
.. _github-stats:
Github stats
============

GitHub stats for 2013/07/31 - 2014/10/18 (tag: v1.3.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

The following 169 authors contributed 2105 commits.

* Adam Heck
* Adrian Price-Whelan
* Alex Loew
* Alistair Muldal
* Andrea Bedini
* Andreas Wallner
* Andrew Dawson
* Andrew Merrill
* Aseem Bansal
* Behram Mistree
* Ben Cohen
* Ben Gamari
* Ben Keller
* Ben Root
* Benjamin Reedlunn
* Brandon Liu
* CJ Carey
* Cameron Davidson-Pilon
* Carissa Brittain
* Carwyn Pelley
* Chris Beaumont
* Chris G
* Christoph Gohlke
* Christoph Hoffmann
* Cimarron Mittelsteadt
* Damon McDougall
* Daniel O'Connor
* Dara Adib
* David Anderson
* Dean Malmgren
* Dmitry Lupyan
* DonaldSeo
* Elliott Sales de Andrade
* Eric Firing
* Eugene Yurtsev
* Federico Ariza
* Felipe
* Filipe
* Francesco Montesano
* Francis Colas
* Geoffroy Billotey
* Gregory Ashton
* Guillaume Gay
* Gustavo Braganca
* Hans Meine
* Hans Moritz Günther
* Ian Thomas
* Jae-Joon Lee
* Jake Vanderplas
* JamesMakela
* Jan Schulz
* Jason Grout
* Jason Miller
* Jens Hedegaard Nielsen
* Joe Kington
* Joel B. Mohler
* Jorrit Wronski
* José Ricardo
* Jouni K. Seppänen
* Julian Taylor
* JulianCienfuegos
* Katy Huff
* Kevin Chan
* Kevin Keating
* Kristen M. Thyng
* Larry Bradley
* Lennart Fricke
* Leo Singer
* Loïc Séguin-C
* Magnus Nord
* Maksym P
* Manuel GOACOLOU
* Marianne Corvellec
* Markus Roth
* Martin Dengler
* Martin Fitzpatrick
* Martin Spacek
* Matt Klein
* Matt Terry
* Matthew Brett
* Matthias Bussonnier
* Matthieu Caneill
* Matěj Týč
* Michael
* Michael Droettboom
* Michiel de Hoon
* Michka Popoff
* Mikhail Korobov
* MinRK
* Nelle Varoquaux
* Nic Eggert
* Nicolas P. Rougier
* Oliver Willekens
* Patrick Marsh
* Paul
* Paul Hobson
* Paul Ivanov
* Per Parker
* Peter Iannucci
* Peter Würtz
* Phil Elson
* Pierre Haessig
* Puneeth Chaganti
* Remi Rampin
* Richard Hattersley
* Ricky
* Robert Johansson
* Rohan Walker
* Roland Wirth
* RutgerK
* Ryan Blomberg
* Ryan D'Souza
* Ryan May
* Scott Lasley
* Scott Lawrence
* Scott Stevenson
* Sergey Kholodilov
* Silviu Tantos
* Simon Gibbons
* Thomas A Caswell
* Thomas Hisch
* Thomas Robitaille
* Till Stensitzki
* Timo Vanwynsberghe
* Tobias Megies
* Todd Jennings
* Tony S Yu
* Tor Colvin
* Trevor Bekolay
* Vadim Markovtsev
* Valentin Haenel
* Viktor Kerkez
* Vlad Seghete
* Wieland Hoffmann
* William Manley
* Yaron de Leeuw
* anykraus
* arokem
* aszilagyi
* blackw1ng
* blah blah
* captainwhippet
* chebee7i
* danielballan
* davidovitch
* daydreamt
* donald
* endolith
* fardal
* grdlok
* jowr
* kcrisman
* kelsiegr
* khyox
* kramer65
* kshramt
* limtaesu
* marky
* profholzer
* rahiel
* rhoef
* sfroid
* spiessbuerger
* stahlous
* syngron
* ugurthemaster
* vagrant
* vbr
* xbtsw


We closed a total of 1964 issues, 622 pull requests and 1342 regular issues;
this is the full list (generated with the script 
:file:`tools/github_stats.py`):

Pull Requests (622):

* :ghpull:`3672`: Python3 pep8 fixes
* :ghpull:`3558`: Adds multiple histograms side-by-side example
* :ghpull:`3665`: Remove usage of raw strides member in _backend_gdk.c
* :ghpull:`3309`: Explicitly close read and write of Popen process (latex)
* :ghpull:`3662`: Make all classes new-style.
* :ghpull:`3646`: Remove PyCXX dependency for core extension modules
* :ghpull:`3664`: [examples] pep8 fix e251 e27*
* :ghpull:`3294`: fix typo in figlegend_demo.py
* :ghpull:`3666`: remove print from test
* :ghpull:`3638`: MNT : slight refactoring of Gcf
* :ghpull:`3387`: include PySide in qt4agg backend check
* :ghpull:`3597`: BUG/TST : skip example pep8 if don't know source path
* :ghpull:`3661`: Numpy 1.6 fixes
* :ghpull:`3635`: fix pep8 error classes e20[12] and e22[12] in examples
* :ghpull:`3547`: Don't use deprecated numpy APIs
* :ghpull:`3628`: Document auto-init behavior of colors.Normalize and cm.ScalarMappable.
* :ghpull:`3640`: figure.max_num_figures was renamed to figure.max_open_warning.
* :ghpull:`3650`: Typo fixes. [backport to doc branch]
* :ghpull:`3564`: Rcparam validation fix
* :ghpull:`3642`: TST : know-fail shadding tests
* :ghpull:`3632`: Fix for #3623
* :ghpull:`3619`: PatchCollection: pass other kwargs for match_original=True
* :ghpull:`3637`: typo: mp4 -> mpeg4. Closes #3636.
* :ghpull:`3629`: examples: fix pep8 error class E211
* :ghpull:`3622`: setup.py creates a zombie C extension called "freetype2"
* :ghpull:`3627`: Fixed Image and Renderer pickling
* :ghpull:`3515`: examples: fix pep8 error classes E111 and E113
* :ghpull:`3625`: animate_decay.py example code is less complicated
* :ghpull:`3621`: matplotlib.__version__ is now unicode as of 1.4.0
* :ghpull:`3620`: Revert interactive determination
* :ghpull:`3613`: Fix problem with legend if data has NaN's [backport to 1.4.x]
* :ghpull:`3313`: BUG: 3 fixes for widgets (MultiCrusor, SpanSelector, Slider)
* :ghpull:`3496`: BUG : fix str vs bytes issue in py3 in ps backend
* :ghpull:`3609`: Nbagg icons
* :ghpull:`3611`: Fix spelling error
* :ghpull:`3600`: BUG: now only set 'marker' and 'color' attribute of fliers in boxplots
* :ghpull:`3560`: Updated whats new for nbagg and legend/patheffects docs.
* :ghpull:`3594`: Unicode decode error [backport to 1.4.x]
* :ghpull:`3574`: `rotation` parameter has no effect on `RegularPolyCollection`
* :ghpull:`3409`: Win fixes
* :ghpull:`3595`: Some small doc fixes only relevant on the master branch
* :ghpull:`3291`: Lightsource enhancements
* :ghpull:`3592`: Fix crash in picking for zero-length path collection
* :ghpull:`3585`: merge V1.4.0-doc into v1.4.x 
* :ghpull:`3566`: BUG : don't assume label in boxpplot_stat
* :ghpull:`3567`: Fixed the differencing of images for the webagg/nbagg backends.
* :ghpull:`3571`: BUG : deal with empty list passed to boxplot
* :ghpull:`3533`: BUG : fix handling of flierprop by boxplot
* :ghpull:`3514`: Ticks on top axis disappear if tick size is too large (when using bbox_inches='tight')
* :ghpull:`3578`: Fixes test to assert instead of print
* :ghpull:`3575`: Supports locale-specified encoding for rcfile.
* :ghpull:`3479`: Build dep updates
* :ghpull:`3552`: Nbagg enhancements
* :ghpull:`3559`: Install texlive and other dependencies when building docs.
* :ghpull:`3555`: Typo in comment documentation for example timers.py
* :ghpull:`3556`: copy/paste corrections in test_backend_qt5
* :ghpull:`3545`: Provide an informative error message if something goes wrong in setfont [backport to 1.4.x]
* :ghpull:`3548`: Silence some Sphinx warnings by rewriting docstrings.
* :ghpull:`3539`: DEP : update six minimum version
* :ghpull:`3543`: DOC : fix main-page tags
* :ghpull:`3524`: Bug in AutoDateLocator when dates are in reverse order
* :ghpull:`3464`: BUG : nbagg py3k compatibility
* :ghpull:`3534`: BUG : fixes whis over-writing in boxplot_stats
* :ghpull:`3535`: BUG/DOC : Correct default value listed in docstring
* :ghpull:`3369`: Added legend.framealpha to rcParams, as mentioned in axes.legend docstring
* :ghpull:`3510`: Fix setupext [backport to 1.4.x]
* :ghpull:`3530`: Only insert links to pdfs if we are actually generating these.
* :ghpull:`3487`: Can not import matplotlib when launching from non-ascii path 
* :ghpull:`3526`: BUG : fix eps corruption when using clipping
* :ghpull:`3492`: Allow python 3 version of PyCXX
* :ghpull:`3521`: More doc fixes
* :ghpull:`3513`: examples: fully automated fixing of E30 pep8 errors
* :ghpull:`3461`: This fixes a bunch of Sphinx warnings
* :ghpull:`3507`: general pep8 fixes 
* :ghpull:`3506`: Named colors example, figure size correction [backport to 1.4.0-doc]
* :ghpull:`3503`: Win fix simple
* :ghpull:`3495`: BUG : don't use super(self.__class__, self)
* :ghpull:`3501`: Bugfix for text.xytext property
* :ghpull:`3376`: Move widget.{get,set}_active to AxisWidget.
* :ghpull:`3419`: Better repr for Bboxes.
* :ghpull:`3474`: call set cursor on zoom/pan toggle [backpont to 1.4.x]
* :ghpull:`3425`: Pep8ify examples
* :ghpull:`3477`: Better check for required dependency libpng
* :ghpull:`3478`: BUG : restore back-compatibility of regisiter_backend
* :ghpull:`2900`: Remove no-longer-necessary KnownFail for python 3.2.
* :ghpull:`3467`: Bugfix in mlab for strided views of np.arrays [backport to 1.4.x]
* :ghpull:`3469`: Fix handling of getSaveFileName to be consistent [backport to 1.4.x]
* :ghpull:`3384`: Test marker styles
* :ghpull:`3456`: DOC : add known-bug + fix for QT5 toolbar issue
* :ghpull:`3458`: DOC : minor import tweaks
* :ghpull:`3457`: Add Qt5Agg to backends in matplotlibrc.template.
* :ghpull:`3422`: Use mailmap in github stats
* :ghpull:`3429`: DOC : added pytz to optional dependencies docs
* :ghpull:`3453`: Bbox rebase 14
* :ghpull:`3427`: DOC : added DOI link to citing.html
* :ghpull:`3438`: Get rid of unused pre python 2.6 code in doc make.py
* :ghpull:`3414`: Fixes TypeError when installing without freetype
* :ghpull:`3428`: DOC : add caveat about freetype 2.3
* :ghpull:`3430`: DOC : fixed markup / boxplot text in whats_new
* :ghpull:`3426`: DOC : remove piwik code
* :ghpull:`3432`: Update whats_new.rst
* :ghpull:`3415`: DOC: fix markup and download link in the Windows install section
* :ghpull:`3408`: test_text Modify filter warning regex
* :ghpull:`3282`: Catch warning thrown in Mollweide projection.
* :ghpull:`2635`: Crash on saving figure if text.usetex is True
* :ghpull:`3241`: Cast to integer to get rid of numpy warning
* :ghpull:`3335`: Fix and new test for #3327
* :ghpull:`3278`: Use libpng-config if available
* :ghpull:`3244`: Filter warnings in rcparams test (and others)
* :ghpull:`3378`: BUG: Fixes custom path marker sizing for issue #1980
* :ghpull:`3401`: enlarge on windows build instructions slightly
* :ghpull:`3399`: Cherrypick doc changes to v1.4.0
* :ghpull:`3397`: Install guide tweaks
* :ghpull:`3394`: DOC : add note about np.matrix and pandas objects
* :ghpull:`3390`: Move stylelib directory to mpl-data
* :ghpull:`3381`: BUG : make qApp global before using it
* :ghpull:`3380`: Remove residual mention of TODO file, which no longer exists.
* :ghpull:`3349`: DOC : added folders for api_changes and whats_new
* :ghpull:`3360`: BUG : modified logic on starting qApp
* :ghpull:`3372`: DOC: Fixed the wording of the deprecation warning
* :ghpull:`3363`: Identification of freetype when 'freetype-config --ftversion' fails.
* :ghpull:`3359`: PEP8 conformity; removed outcommented code
* :ghpull:`3357`: backend_qt5.py Don't use six.u
* :ghpull:`3287`: DOC: comprehensive rewrite for OSX binary install
* :ghpull:`3337`: BUG : don't assign color to flier props if None
* :ghpull:`3342`: AGG link changed. Also fix other doc warnings
* :ghpull:`3262`: 1.4.0 RC1: --ftversion vs --version freetype version
* :ghpull:`3322`: Fixed error with QSizePolicy
* :ghpull:`3339`: Fix mathmpl images not showing in HTML Help (CHM)
* :ghpull:`3331`: Restore compatibility with Python 3.2
* :ghpull:`3324`: Fix #3304.
* :ghpull:`3325`: ENH: add HTML Help builder option
* :ghpull:`3329`: Workaround for Sphinx not escaping ``_`` (underscore) for tex output
* :ghpull:`3323`: Replaced unicode() function by six.text_type
* :ghpull:`3301`: Colormap choice guidelines in documentation - based on talk at SciPy 2014
* :ghpull:`3320`: DOC: Fix Malformed table. Text in column margin
* :ghpull:`3317`: TST: Fix test_animation RuntimeErrors on Windows
* :ghpull:`3310`: Fix MatplotlibDeprecationWarning: The "loc" positional argument to legend is deprecated
* :ghpull:`3312`: BUG: fix test error when ghostscript not installed
* :ghpull:`3306`: BUG : restore allow_rasterization on PolyCollection
* :ghpull:`3302`: Check for GhostScript in this test which needs it
* :ghpull:`3194`: Annotate bbox darrow
* :ghpull:`3277`: MNT : better error handling on determining gs version
* :ghpull:`3300`: Quiver3d fixes
* :ghpull:`3284`: BUG : fix  _reshape_2D bug with [(n, 1), ..] input
* :ghpull:`3296`: V1.4.x
* :ghpull:`3295`: Use the interpolation parameter in make_thumbnail
* :ghpull:`3235`: Silence some more warnings
* :ghpull:`3274`: BUG : fixes FontProperties memory leak
* :ghpull:`3275`: TST: Fix ImportError: No module named 'mpl_toolkits'
* :ghpull:`3250`: Fix WindowsError: [Error 32] The process cannot access the file
* :ghpull:`3247`: Usage faq
* :ghpull:`3270`: DOC : windows install docs from cgohlke
* :ghpull:`3257`: MRG: refactor and bugfixes for plot_directive
* :ghpull:`3238`: OSX install
* :ghpull:`3258`: Fix various memory leaks discovered through valgrind
* :ghpull:`3253`: Stop make.py removing generated documentation figs
* :ghpull:`3269`: Upload artifacts only on main repository.
* :ghpull:`3251`: Add animation.convert_path setting to matplotlibrc.template
* :ghpull:`3266`: remove obsolete TODO files
* :ghpull:`3261`: Get rid of warning about GTK3Agg with python3
* :ghpull:`3249`: TST: Fix test_backend_ps failures on Windows
* :ghpull:`3217`: Added some function arguments to the documentation for FuncAnimation
* :ghpull:`3243`: Fixed backend workflow.
* :ghpull:`3246`: Fix some hyperlinks in the documentation
* :ghpull:`3004`: FAQ and unit/ still refers to nxutils
* :ghpull:`3239`: Fix auto-closing in PolyCollection
* :ghpull:`3193`: Fix plot directive when used with multiple options.
* :ghpull:`3236`: Test PEP8 stuff in separate Travis build.
* :ghpull:`3188`: Np error patch
* :ghpull:`3154`: whitelist mpl_toolkits tests
* :ghpull:`3230`: DOC : added note about useoffset rcparam
* :ghpull:`3228`: DOC : top_level doc-string clean up
* :ghpull:`3190`: Adding two new styles to mplstyles
* :ghpull:`3215`: Close files in animation to silence some warning in the test suite on python3 
* :ghpull:`3237`: Fix Collection3D. Fixes legend for scatter3d
* :ghpull:`3233`: Update numpy version in setup.py
* :ghpull:`3227`: Whats new cleaning
* :ghpull:`3224`: Fix lots of warnings in docs/Examples that crash
* :ghpull:`3229`: DEP : bump min numpy to 1.6
* :ghpull:`3222`: add reduce to the list of imports from six.moves
* :ghpull:`3126`: insertion of Annotation class docs into annotate docstring broken
* :ghpull:`3221`: Fixes #3219 by ignoring pep8 noncomplicant auto-generated file.
* :ghpull:`2227`: Refactor of top-level doc/README.rst
* :ghpull:`3211`: Mplot3d/depthshade
* :ghpull:`3184`: DOC : added warning to doc of get_window_extent
* :ghpull:`3165`: Bug restore boxplot defaults
* :ghpull:`3207`: Fix memory leak in tostring_rgba_minimize(). (#3197)
* :ghpull:`3210`: Fix PEP8 error.
* :ghpull:`3203`: Make type1font.py work better on Python 3.x
* :ghpull:`3155`: BUG : fix fetch of freetype version during build
* :ghpull:`3192`: TST : drop 3.2, add 3.4
* :ghpull:`3121`: Added 'PyQt4v2' to valid values for backend.qt4
* :ghpull:`3167`: BUG : raise exception in subplot if num out of range
* :ghpull:`3208`: Add missing import of unichr from six.
* :ghpull:`3156`: DOC : added whats_new entry for Qt5 backend
* :ghpull:`2843`: BUGFIX:  This change fixes #2475, where contour labels added manually
* :ghpull:`3201`: Revert "[examples/api] autopep8 + use np.radians/np.degree where appropr...
* :ghpull:`3200`: Revert "pep8ify more examples in examples/ + use np.radians/np.degrees"
* :ghpull:`3174`: MNT : replace and deprecated qt4_compat
* :ghpull:`3112`: BUG : patches.Wedge.set_radius set wrong attribute
* :ghpull:`2952`: BUG : turned clipping off on pie chart components
* :ghpull:`2951`: BUG/API : tweaked how AnchoredSizeBar handles font properties
* :ghpull:`3157`: BLD : fix build on windows
* :ghpull:`3189`: BUG: use unittest.mock for Python 3.3+
* :ghpull:`3045`: Use less aggressive garbage collection
* :ghpull:`3185`: DOC : added details about r/cstride in plot3d
* :ghpull:`3182`: pep8ify more examples in examples/ + use np.radians/np.degrees
* :ghpull:`3181`: [examples/api] autopep8 + use np.radians/np.degree where appropriate
* :ghpull:`3163`: DOC : documented bottom kwarg of hist
* :ghpull:`3180`: DOC: Fix order of parameters in ax.text docstring.
* :ghpull:`3168`: DOC : add prominent doc about set_useOffset
* :ghpull:`3162`: BLD : made tornado an optional external package
* :ghpull:`3169`: Update pyplot_tutorial.rst
* :ghpull:`3084`: Improving plt.hist documentation
* :ghpull:`3160`: Glade tutorial branch fixed
* :ghpull:`3008`: Nbagg backend
* :ghpull:`3164`: fix bad pathing in whats_new.rst
* :ghpull:`3159`: BUG : fix qt4 backends
* :ghpull:`3158`: backend_pgf: Error message for missing latex executable (fix #3051)
* :ghpull:`3125`: DOC : added annotation example to arrow docstring
* :ghpull:`3149`: 3dquiver rebranch
* :ghpull:`3141`: BUG: Fix 'TypeError: expected bytes, str found' on Python 3
* :ghpull:`3072`: Implement backend for PyQt5 + modify Qt4 backends to use Qt5 module via shim
* :ghpull:`3153`: Avoid floating point sensitivity in trisurf3d test
* :ghpull:`3147`: Fix doc for sharey keyword in pyplot.subplots.
* :ghpull:`3133`: Doc cleanup
* :ghpull:`3110`: BUG: Add Figure.delcolorbar() to fully delete a colorbar
* :ghpull:`3131`: DOC : sixify unichr
* :ghpull:`3132`: DOC : added note about maintain ref to widgets
* :ghpull:`2927`: BUG : don't use mutable objects as dictionary keys
* :ghpull:`3122`: DOC: mention Anaconda; clean some old junk out of the FAQ
* :ghpull:`3130`: Scatter set sizes whats new
* :ghpull:`3127`: DOC : added inherited-members to Axes autodoc
* :ghpull:`3128`: Axes aspect doc
* :ghpull:`3103`: errorbar: fmt kwarg defaults to None; use 'none' to suppress plot call
* :ghpull:`3123`: DOC : add documentation to Polygon methods
* :ghpull:`3120`: typo fix
* :ghpull:`3099`: New animation example (Joy Division's Unchained Love cover)
* :ghpull:`3111`: bug fix: check the type of the 'key' of the two array 'r1' and 'r2'
* :ghpull:`3108`: DOC : clarified doc of add_artist
* :ghpull:`3107`: Bug-fix for issue 3106
* :ghpull:`3092`: Adds check that rgb sequence is of length 3
* :ghpull:`3100`: Use autolim kwarg in add_collection to prevent duplication of effort.
* :ghpull:`3104`: BUG: in Spine.set_position(), preserve most Axis info.
* :ghpull:`3101`: Streamplot: clean up handling of masks, eliminate warning in test.
* :ghpull:`3102`: Image: handle images with zero columns or rows.
* :ghpull:`2929`: clip_on documentation note/warning
* :ghpull:`3067`: Fix for bug #3029.
* :ghpull:`3078`: fix argument checks in axis/base.margins
* :ghpull:`3089`: Fix log hist y-axis minimum with weighted data
* :ghpull:`3087`: small error in comment
* :ghpull:`2996`: Violin Plots
* :ghpull:`3053`: symlog-scale: Remove asssert linscale >= 1.
* :ghpull:`3077`: Invalidate font manager when rcParam family lists change.
* :ghpull:`3081`: Points to pixels
* :ghpull:`3080`: Minor fix to commit 24bc071
* :ghpull:`3076`: Bug: backend_pdf: UnicodeDecodeError: 'ascii' codec can't decode byte 0xe2
* :ghpull:`3074`: TST : force re-building of font-cache
* :ghpull:`2874`: Fix for issue #2541 (revised)
* :ghpull:`2662`: allow slice and fancy indexing to only show some markers 
* :ghpull:`2855`: ENH Added the origin option to `spy`
* :ghpull:`3022`: Updating PyQt version checks for v4.10+
* :ghpull:`3015`: Date stem simplefix
* :ghpull:`3017`: Do not provide (wrong) mtext instances for pre-layouted text blocks (fixes #3000)
* :ghpull:`3009`: BUG: Showing a BboxImage can cause a segmentation fault
* :ghpull:`3061`: Add Axes.add_image() for consistency.
* :ghpull:`3063`: Change EPD links to Enthought Canopy
* :ghpull:`3050`: Animation example: rain drops
* :ghpull:`2898`: Fix animation errors
* :ghpull:`3031`: avoid np.nan values in colors array returned by axes3d._shade_colors
* :ghpull:`3038`: BUG : expand x/y range in hexbin if singular
* :ghpull:`3018`: Fix documentation of entropy function
* :ghpull:`3036`: Unicode fixes
* :ghpull:`2871`: Add a colorblind friendly heatmap.
* :ghpull:`2879`: BLD : adjust min six version to 1.3
* :ghpull:`3037`: DEP : removed levypdf from mlab
* :ghpull:`3025`: mpl issue: #2974 - documentation corrected
* :ghpull:`3030`: Fix minor typo in customisation docs
* :ghpull:`2947`: Re-Generate legend, through apply_callback/Apply
* :ghpull:`3014`: BUG : improved input clean up in Axes.{h|v}line
* :ghpull:`2771`: Fix font family lookup calculation
* :ghpull:`3007`: #3005 - Removed 'ipython -pylab' references
* :ghpull:`2946`: remove .rect member (clashes with QWidget)
* :ghpull:`2837`: EXP : turn of clipping in spine example
* :ghpull:`2772`: BUG : instantiate fall-back writer
* :ghpull:`2922`: ENH : add flag to box_plot and bxp to manage (or not) xticks
* :ghpull:`2950`: DOC : edits to optional dependencies
* :ghpull:`2995`: Added 'interpolation_none_vs_nearest' example, without .DS_store files
* :ghpull:`3002`: BUG/DOC : fix bad merge of INSTALL
* :ghpull:`2993`: Avoid a null-pointer dereference in _tri.cpp
* :ghpull:`2994`: Minor fixes in _macosx.m
* :ghpull:`2997`: Disable copying of C++ classes with nontrivial destructors
* :ghpull:`2992`: Remove a few dead assignments
* :ghpull:`2991`: Silence some compiler warnings related to ft2font
* :ghpull:`2989`: Don't call Py_DECREF on null in _ttconv.cpp
* :ghpull:`2984`: small error in install faq
* :ghpull:`2829`: (fix #2097) PGF: get fonts from fc-list, use builtin fonts for tests
* :ghpull:`2913`: Allow :context: directive to take 'reset' option. Fixes #2892.
* :ghpull:`2914`: Don't close figure if context and apply_rcparams are both set.
* :ghpull:`2983`: DOC/BUG : fixed sphinx markup
* :ghpull:`2981`: TST: __spec__ (an import-related variable for modules) was added in pyth...
* :ghpull:`2978`: BUG: EllipseCollection: fix transform error
* :ghpull:`2968`: BUG: Fix the triangular marker rendering error.
* :ghpull:`2966`: axvline doc typo fix
* :ghpull:`2962`: py3k fix
* :ghpull:`2739`: DOC : improved `extent` of `imshow` doc
* :ghpull:`2960`: PEP8 : making pep8 happy again
* :ghpull:`2836`: DOC/ENH : get/set_size_inches
* :ghpull:`2948`: DOC : added missing doc changes from #2844
* :ghpull:`1204`: Add power-law normalization
* :ghpull:`2452`: Fixed issues with errorbar limits
* :ghpull:`2955`: PEP8 : add missing line to un-break build
* :ghpull:`2926`: BUG: Removes iteration over locals (no-no) in mathtext
* :ghpull:`2915`: Consistency of the radius argument for Path.points_in_path
* :ghpull:`2939`: Fixes a bug in drawing bitmap images in the macosx backend for handling device scaling
* :ghpull:`2949`: CLN : removed version check that required numpy > 1.2
* :ghpull:`2848`: DOC : removed line about un-needed dependencies in Windows
* :ghpull:`2940`: Fix some documentation mistakes
* :ghpull:`2933`: #2897 Adding tests for pie ccw. Issue 2897
* :ghpull:`2923`: Issue 2899
* :ghpull:`2930`: Cranky pep8
* :ghpull:`2847`: DOC : add link to `plt.subplots` from `Figure.add_subplot`
* :ghpull:`2906`: Fix Cairo text on Python3 with pycairo
* :ghpull:`2920`: fix six check message
* :ghpull:`2912`: Fix paths in doc which are searched for matplotlibrc (XDG).
* :ghpull:`2735`: Fixes issue #966: When appending the new axes, there is a bug where it
* :ghpull:`2911`: text_axes missing cleanups
* :ghpull:`2834`: WebAgg: Fix IPython detection.  Fix encoding error on Python 3
* :ghpull:`2853`: counterclock parameter for pie
* :ghpull:`1664`: Support for skewed transforms
* :ghpull:`2844`: BUG : Qt repaint workaround on windows
* :ghpull:`2895`: typos: s/coodinate/coordinate & s/contols/controls
* :ghpull:`2875`: Fix for issue #2872. Skip NaN's in draw_path_collection.
* :ghpull:`2887`: fix a bug introduced in c998561d6cc1236
* :ghpull:`2884`: Fixed the failing tests on master.
* :ghpull:`2851`: Fix positional/kwarg handling of the Z argument
* :ghpull:`2852`: AttributeError: 'module' object has no attribute 'next'
* :ghpull:`2860`: Fix subprocess.CalledProcessError on Google App Engine
* :ghpull:`2865`: WebAgg: raise WebAggApplication.started flag before blocking
* :ghpull:`2867`: GTK3 backend: implemented FigureCanvasBase.resize_event()
* :ghpull:`2858`: BUG: colorbar autoscaling now ensures a finite range of values
* :ghpull:`2849`: WebAgg issue - Uncaught SyntaxError: Unexpected token & 
* :ghpull:`2854`: DOC hist is not cumulative by default
* :ghpull:`2825`: WebAgg: extracted figure_div style into css and changed layout
* :ghpull:`2444`: Fixed bad vector transforms.
* :ghpull:`2731`: 2d padding
* :ghpull:`2846`: Fix bug in horizontal step histograms (#2830)
* :ghpull:`2819`: DOC: clarified docstring for cbook.boxplot_stats
* :ghpull:`2835`: quiver: handle autoscaling with quiverkey when animated
* :ghpull:`2838`: TST : make 3.2 pass again
* :ghpull:`2826`: GTK3 backend: Replaced deprecated GObject calls with GLib
* :ghpull:`2805`: ENH: Updated inset locator axes to return a HostAxes by default
* :ghpull:`2807`: Python 3 METH_VARARGS with METH_KEYWORDS
* :ghpull:`2821`: DOC: point downloads at the matplotlib downloads
* :ghpull:`2813`: GTK3Agg backend: Only convert the cairo context to a cairocffi context o...
* :ghpull:`2801`: Named colors example
* :ghpull:`2784`: Scipy2013 Sprint: Cleaning F/C example
* :ghpull:`2798`: Added remove methods for legends in figure and axes objects
* :ghpull:`2799`: Xdg message repr
* :ghpull:`2781`: Triplot returns the artist it adds.
* :ghpull:`2774`: changed the text of INSTALL to be correct about what external
* :ghpull:`2788`: MEP12: Clean-up line and marker demos
* :ghpull:`2787`: Empty event loop
* :ghpull:`2779`: remove old animtion examples.
* :ghpull:`2794`: fix typo in documentation
* :ghpull:`2793`: missing mask for scroll event
* :ghpull:`2780`: ENH : improve error invalid error message for subplot
* :ghpull:`2782`: BUG: quiverkey must set the vector figure attribute
* :ghpull:`2389`: table.py: fix issue when specifying both column header text and color
* :ghpull:`2755`: Fixes legend.get_children() to actually return the real children of
* :ghpull:`2599`: Create interpolation_methods.py
* :ghpull:`2621`: Simplify and fix dpi handling in tight_bbox
* :ghpull:`2752`: Make standardization of input optional in mlab.PCA
* :ghpull:`2726`: Don't snap pcolor
* :ghpull:`2732`: AttributeError: 'Patch3DCollection' object has no attribute 'set_sizes'
* :ghpull:`2442`: Rewrite of the entire legend documentation, including tidy ups of code and style to all things "legend".
* :ghpull:`2746`: ENH : added warning on annotate
* :ghpull:`2675`: clip_on = False does not work for x-axis
* :ghpull:`1193`: Cairo backend ignores alpha in imshow. 
* :ghpull:`2768`: DOC/BUG: Fix references to demo files
* :ghpull:`2744`: handle NaN case nicely in _is_sorted
* :ghpull:`2761`: Fix line color handling
* :ghpull:`2763`: double_pendulum_animated.py in 1.2.1 fails due to clear_temp kwarg
* :ghpull:`2756`: Removes artificial limit in artist picker traversal. There are quite a
* :ghpull:`2555`: Make it possible to add mpl.rcParams to itself or deepcopy
* :ghpull:`2558`: fixes issue #2556
* :ghpull:`2762`: BUG : makes Axes.margins work with just kwargs
* :ghpull:`2643`: ENH/REF: Overhauled boxplots
* :ghpull:`2734`: Fixed issue #1733 - AxesImage draw function now takes into account the
* :ghpull:`2757`: Added missing warnings import
* :ghpull:`2753`: BUG : fixes py3k import
* :ghpull:`1227`: Does the gtk3agg backend work on python3?
* :ghpull:`2751`: BUG : fix failing test on 3.2
* :ghpull:`2749`: Qt4 keys
* :ghpull:`2137`: PIL -> Pillow
* :ghpull:`2705`: Build fails on OS X with NumPy 1.9
* :ghpull:`2707`: Callable date formatter
* :ghpull:`1299`: Update Axes3D.tricontour for custom triangulations
* :ghpull:`2474`: MEP12: Example clean-up for reference
* :ghpull:`2727`: Typo in explanation of annotation_demo
* :ghpull:`2728`: fixed comment white space pep8
* :ghpull:`2720`: Look for user-specified styles in ~/.config/matplotlib/stylelib
* :ghpull:`2712`: Anchored sizebar fontprop
* :ghpull:`2713`: Compare pep
* :ghpull:`2207`: color of candlestick lines
* :ghpull:`2551`: Fix behavior of hist function when passed empty dataset
* :ghpull:`2595`: EHN: add a span_stays option to widget.SpanSelector
* :ghpull:`2647`: use GridSpec in plt.subplots
* :ghpull:`2725`: DOC : fixes small typos in matplotlib.dates docs
* :ghpull:`2714`: Deprecated matplotlib.testing.image_util.
* :ghpull:`2691`: Change LogFormatterExponent to consistently format negative exponents
* :ghpull:`2719`: Package initialization made possible when executed in environments with...
* :ghpull:`2718`: Added missing cleanup decorator import.
* :ghpull:`2248`: axes_grid1: ImageGrid respect the aspect ratio of axes. 
* :ghpull:`2481`: datestr2num of year and month fails on 29th, 30th, and 31st of month
* :ghpull:`2423`: Off-axes markers unnecessarily saved to PDF
* :ghpull:`2239`: Update of mlab.pca - updated docstring, added saving the eigenvalues.
* :ghpull:`2711`: Fixes issue #2525
* :ghpull:`2704`: Bugfix for issue #1747. Allows removal of figure text artists.
* :ghpull:`2696`: Fix Tk keyboard modifier masks on Windows
* :ghpull:`2690`: Build failure on MacOS X 10.5.8 (PowerPC G5) with Python 3.3.3
* :ghpull:`2628`: improved get_ticklabels kwarg
* :ghpull:`2634`: address FuncAnimantion trying to take lengths of generators
* :ghpull:`2468`: Add "sage" colors to colors.py
* :ghpull:`2521`: Fix backend_svg.RendererSVG.draw_text to render urls
* :ghpull:`2703`: Updating regex used to split sphinx version string.
* :ghpull:`2701`: Fix FancyBboxPatch Typo
* :ghpull:`2700`: Consistent grid sizes in streamplot.
* :ghpull:`2689`: Disable offset box clipping by default.
* :ghpull:`2693`: Use mpl.checkdep_ghostscript function to find ghostscript
* :ghpull:`2679`: Make `test_save_animation_smoketest` actually run
* :ghpull:`2504`: Using qhull for Delaunay triangulation
* :ghpull:`2683`: Close a figure with a type long or uuid figure number
* :ghpull:`2677`: Make sure self._idle is set to `True` in all cases
* :ghpull:`2597`: BUG: Add subplot spec  eq  
* :ghpull:`2650`: Lightsource shade method parameters for color range definition
* :ghpull:`2665`: MacOSX backend supports 2x DPI images and MathTeX.
* :ghpull:`2680`: Deprecate toolbarqt4agg
* :ghpull:`2685`: Remove a redundant comparison that raises an exception in Python 3
* :ghpull:`2657`: different fix for comparing sys.argv and unicode literals
* :ghpull:`2646`: Fix Gtk3 crash when running inside of IPython
* :ghpull:`2661`: NF - see axes.get_label() when clicking on Edit curves lines and axes pa...
* :ghpull:`2676`: Fix typo in _axes.vlines doc-string
* :ghpull:`2569`: Explicitly cast the input array to float before doing anything to it
* :ghpull:`2671`: Deprecate IPython-related Sphinx extensions
* :ghpull:`2656`: Use IPython's copy of ipython_console_highlighting Sphinx ext, if available
* :ghpull:`2515`: overloaded `_make_twin_axes` on `LocateableAxesBase` 
* :ghpull:`2659`: DOC: Remove redundant colormaps from examples
* :ghpull:`2636`: "\usepackage[russian]{babel}" does not work in matplotlib 1.3.1
* :ghpull:`2648`: Update backend_webagg.py
* :ghpull:`2641`: plot_date: Set the default fmt to 'o'
* :ghpull:`2645`: Add option to show/hide the source link in plot_directive
* :ghpull:`2644`: Small typo in the license.
* :ghpull:`2461`: New style format str
* :ghpull:`2503`: Fix interactive mode detection
* :ghpull:`2640`: Axes.plot: remove set_default_color_cycle from the docstring
* :ghpull:`2639`: BUGFIX: ensure that number of classes is always of type INT in Colormap
* :ghpull:`2629`: backend_qt4agg: remove redundant classes.  Closes #1151.
* :ghpull:`2594`: New layout for qt4 subplottool + QMainWindow -> QDialog
* :ghpull:`2623`: setupext: put pkg-config -I, -L, -l locations at the head of the list
* :ghpull:`2610`: improve docstring and add test fot to_rgb(<float>)
* :ghpull:`2618`: Fix issue 1172
* :ghpull:`2619`: slight tweak to mpl_example
* :ghpull:`2626`: minor pep8 to fix failing master builds.
* :ghpull:`2606`: embedding_webagg example: Download button does not work
* :ghpull:`2588`: Refactor mechanism for saving files.
* :ghpull:`2615`: Fixes issue #2482 and adds note in matplotlibrc.template
* :ghpull:`2613`: BLD Fix build failure on Python 3.4b1 for Windows
* :ghpull:`2459`: pep8 for backend_pdf.py
* :ghpull:`2409`: Fix bugs related to bottom kwarg in step histograms
* :ghpull:`2549`: Add methods to control theta position of r-ticklabels on polar plots
* :ghpull:`2567`: more informative exceptions for empty/not-existing images in compare_images()
* :ghpull:`2603`: Correcting bad string comparsion in lin-log plot aspect verification
* :ghpull:`2561`: multi-colored text example
* :ghpull:`2236`: Add easy style sheet selection
* :ghpull:`2582`: fix initialization of AnnotationBbox 
* :ghpull:`2574`: Add axes.titleweight as an rc param
* :ghpull:`2579`: MultiCursor: make events connected during __init__ accessible (for later removal)
* :ghpull:`2591`: Fix infinite recursion in units with ndarray subclasses.
* :ghpull:`2587`: Make backend_pgf more flexible when saving to file-handles or streams (fix #1625).
* :ghpull:`2554`: User Guide Structure
* :ghpull:`2571`: This fixes thee probllem brought up in the mailing list with the recent spectrum improvements
* :ghpull:`2544`: Fix 2542
* :ghpull:`2584`: Fix typo in legend documentation
* :ghpull:`2401`: adds rcParam `axes.formatter.useoffset`
* :ghpull:`2495`: fixed an enconding bug when checking for gs version
* :ghpull:`2581`: AffineBase.__eq__ should not raise an exception when the other does not ...
* :ghpull:`2462`: Path effects update
* :ghpull:`2562`: Just some small tweaks to the recipes
* :ghpull:`2550`: Using a single-shot timer with the Wx backend raises an AttributeError
* :ghpull:`2198`: Fix compilation on Solaris
* :ghpull:`2553`: removing items from the call to six.iteritems
* :ghpull:`2547`: fix removed api change regarding spectral functions
* :ghpull:`2514`: Mpl toolkit pep8
* :ghpull:`2522`: Add additional spectrum-related plots and improve underlying structure
* :ghpull:`2535`: Move external libraries to 'extern' directory - correction
* :ghpull:`2534`: cast argv to unicode before testing
* :ghpull:`2531`: Move external libraries to 'extern' directory
* :ghpull:`2526`: Minor doc fixes
* :ghpull:`2523`: Unicode issue in EPS output when using custom font
* :ghpull:`2479`: Rastized background color
* :ghpull:`2512`: Fix saving to in-memory file-like objects in Postscript backend
* :ghpull:`2472`: Plots using twinx draw on top of figure frame
* :ghpull:`2485`: ENH better error message when wrong cmap name.
* :ghpull:`2491`: Re-enabled PEP8 test, closing #2443.
* :ghpull:`2502`: Updated the docs of pyplot.gca.
* :ghpull:`2428`: BUG: Fixed object type missmatch in SymLogNorm
* :ghpull:`2496`: Adding a missing 'b' back into two 'bbox_' kwargs
* :ghpull:`2494`: Update scatter_demo.py
* :ghpull:`2486`: make pep8 test routine reusable for other projects
* :ghpull:`2480`: Use Pillow always on Travis
* :ghpull:`2406`: BUG: Fixed github stats retrieval
* :ghpull:`2441`: Catch stderr as well as stdout
* :ghpull:`2415`: Bug: alpha parameter was ignored when fill color is #000000
* :ghpull:`2300`: would crash if get_home() returns None
* :ghpull:`2420`: Refactor WebAgg so it can communicate over another web server
* :ghpull:`2447`: BUG: Fix boxplots with manual confidence intervals passed as a numpy array
* :ghpull:`2453`: PdfPages: add option to delete empty file when closed
* :ghpull:`2458`: pep8 clean up 
* :ghpull:`2156`: [Sprint] scatter plots are (reportedly) too slow
* :ghpull:`2464`: Rename C++ variables to avoid use of reserved identifiers
* :ghpull:`2470`: ENH: use checkdep_ghostscript to determine ghostscript executable
* :ghpull:`2469`: BUG: gswin64c.exe not detected on Windows
* :ghpull:`2476`: Updated the position of a few of the text examples because they were overlapping and hard to read.
* :ghpull:`2379`: Make matplotlib.test() print meaninful messages when baseline images are not installed
* :ghpull:`2418`: AssertionError with quiver, quiverkey, and an additional patch.
* :ghpull:`2425`: DOC: `axis_off` wrongfuly appears as a parameter to Figure.add_subplot
* :ghpull:`2445`: Declare Numpy as a setup dependency
* :ghpull:`2336`: Added check in autoscale_None for completely masked pcolor plots.
* :ghpull:`2460`: minor pep8 fix on every file
* :ghpull:`2457`: Privatize Text.cached
* :ghpull:`2433`: Handle Unicode font filenames correctly/Fix crashing MacOSX backend
* :ghpull:`2455`: Gitignore update
* :ghpull:`2446`: Don't set use_2to3 unless we have to.
* :ghpull:`2449`: Qt4 clear before draw
* :ghpull:`2435`: Explicitly catch TypeError when doing pyparsing monkeypatch check
* :ghpull:`2440`: Pdfpages pagecount convenience getter method
* :ghpull:`2437`: Fix randomly failing tests
* :ghpull:`2099`: Updated coding standards test to raise an exception containing the PEP8 failiures.
* :ghpull:`2439`: Use six.string_types instead of basestring.
* :ghpull:`2436`: Catch explicit exceptions when setting locale
* :ghpull:`2430`: Document API change in hist
* :ghpull:`2416`: Multipage pdf with statement
* :ghpull:`2427`: DOC: Add axes_api to documentation after the refactoring
* :ghpull:`2271`: docs: add webagg-backend
* :ghpull:`2417`: Adding possibility to remove invisible lines and patches from relim
* :ghpull:`2242`: DOC:Use monospace for --
* :ghpull:`2426`: Remove dead rms computation
* :ghpull:`2421`: docstring fix
* :ghpull:`2382`: New stlye qt calls
* :ghpull:`2351`: Annotation refactor
* :ghpull:`2408`: backend_pgf: fix str/unicode comparison errors (v1.3.x)
* :ghpull:`2407`: backend_pgf: fix str/unicode comparison errors
* :ghpull:`2404`: Fix backend_ps.py
* :ghpull:`2399`: TypeError occurs when self.button=None in MouseEvents
* :ghpull:`2402`: support tight_bbox for pgf output, fixes #2342 (v1.3.x)
* :ghpull:`2391`:  support tight_bbox for pgf output, fixes #2342
* :ghpull:`2396`: Try UNIXy and Windowsy ways of setting locale
* :ghpull:`2331`: Make optional backends respect setup.cfg
* :ghpull:`2393`: use six.move for cStringIO
* :ghpull:`2372`: Fix step histogram endline
* :ghpull:`2390`: Transparent rcparams
* :ghpull:`2383`: BUG: Fix IndexError: too many indices with numpy 1.8
* :ghpull:`2386`: locale breaks test suite
* :ghpull:`2229`: Matplotlib does not display hatching when rendering to pdf in fill_between
* :ghpull:`2371`: Corrections to cbook.warn_deprecated calls().
* :ghpull:`2381`: don't install python-dateutil==2.1 on python 3.3
* :ghpull:`2380`: check if pyparsing <<= is broken instead of checking the version
* :ghpull:`2374`: Doc fix typos
* :ghpull:`2368`: Set locale for tests
* :ghpull:`2226`: Stop relying on 2to3 and use `six.py` for compatibility instead
* :ghpull:`2335`: make sure we only perform absolute imports on loading a backend
* :ghpull:`2192`: Follow the PSF code of conduct
* :ghpull:`2367`: Fix a number of long-failing tests
* :ghpull:`2363`: [bug correction] trirefine is now independant of triangulation numbering
* :ghpull:`2357`: Better axis limits when using shared axes and empty subplots
* :ghpull:`2358`: Broken IPython notebook integration
* :ghpull:`2352`: changed colorbar outline from a Line2D object to a Polygon object
* :ghpull:`2054`: Ipython/Webagg integration
* :ghpull:`2301`: Upload test result images to Amazon S3
* :ghpull:`2319`: fix draw_idle reference in  NavigationToolbar2
* :ghpull:`2345`: texmanager font selection crashes
* :ghpull:`2307`: font_manager.py UnicodeDecodeError when starting ipython --pylab
* :ghpull:`2306`: Mollweide latitude grid
* :ghpull:`2325`: BF: guard against broken PyQt import
* :ghpull:`2327`: Bar demo2 improve
* :ghpull:`2332`: Except AttributeError when checking for gtk3 backends
* :ghpull:`2340`: Fix #2339: render math text when using path effects
* :ghpull:`2338`: issues with pyparsing 1.5.7 and python 2.7
* :ghpull:`2334`: Remove disabled code.
* :ghpull:`2344`: Fixed the issue of pyplot tutorial missing the show() command
* :ghpull:`2308`: Make pyplot.bar color kwarg less ambiguous
* :ghpull:`2333`: Fix wrong syntax for assert
* :ghpull:`2326`: BUG FIX for Pull Request #2275: Fix incorrect function calls
* :ghpull:`2328`: Fix PySide compatibility
* :ghpull:`2316`: Replace the obsolete wx.PySimpleApp
* :ghpull:`2317`: fix the docstring for scale_docs
* :ghpull:`2110`: Fix rc grid parameter inconsistency
* :ghpull:`2278`: Can't find 64-bit GhostScript on win64
* :ghpull:`2266`: pyparsing version parsing error
* :ghpull:`2262`: View accepts FirstResponder (for key_press_events)
* :ghpull:`2147`: Make nonposy='clip' default for log scale y-axes
* :ghpull:`1920`: finance ochl->ohlc
* :ghpull:`2059`: Pep8 on many tests
* :ghpull:`2275`: Fix Qt4 figure editor color setting and getting
* :ghpull:`2279`: Pyparsing
* :ghpull:`2290`: Fix a recursion problem with masked arrays in get_converter
* :ghpull:`2285`: Handle prop=None case in AnchoredText.__init__()
* :ghpull:`2291`: ENH: use an artist's update() method instead of the setp() function
* :ghpull:`2245`: Adding a flush_events method to the MacOSX backend
* :ghpull:`2251`: Remove deprecated code marked for deletion in v1.3
* :ghpull:`2280`: PEP8 on tri module
* :ghpull:`2282`: Extend search path for PyCXX headers
* :ghpull:`2283`: Incorrect overriding of sys.stdout
* :ghpull:`2158`: Changes to anchored_artists.AnchoredSizeBar
* :ghpull:`1939`: GTK error, failed building on command line
* :ghpull:`2265`: WebAgg favicon serving error in Python 3
* :ghpull:`2267`: Mention `six` in what's new and install docs
* :ghpull:`2261`: WebAgg performance improvements
* :ghpull:`1547`: qt4_editor/formlayout.py TypeError: float() argument must be a string or a number
* :ghpull:`2260`: texmanager font family fix

Issues (1342):

* :ghissue:`3672`: Python3 pep8 fixes
* :ghissue:`3355`: Unneeded argument in get_linestyle
* :ghissue:`3558`: Adds multiple histograms side-by-side example
* :ghissue:`3665`: Remove usage of raw strides member in _backend_gdk.c
* :ghissue:`3309`: Explicitly close read and write of Popen process (latex)
* :ghissue:`3488`: pep8ify examples (part2)
* :ghissue:`3589`: ENH: add to_grayscale() method to color maps
* :ghissue:`3662`: Make all classes new-style.
* :ghissue:`3646`: Remove PyCXX dependency for core extension modules
* :ghissue:`3664`: [examples] pep8 fix e251 e27*
* :ghissue:`3294`: fix typo in figlegend_demo.py
* :ghissue:`3666`: remove print from test
* :ghissue:`3667`: A bug in mpl_toolkits.mplot3d.axes3d
* :ghissue:`3638`: MNT : slight refactoring of Gcf
* :ghissue:`3387`: include PySide in qt4agg backend check
* :ghissue:`3597`: BUG/TST : skip example pep8 if don't know source path
* :ghissue:`3596`: Pep8 tests fails when running python tests.py from base mpl dir.
* :ghissue:`3661`: Numpy 1.6 fixes
* :ghissue:`3660`: shading tests + numpy 1.6
* :ghissue:`3635`: fix pep8 error classes e20[12] and e22[12] in examples
* :ghissue:`3653`: Make ScalarMappable a new-style class.
* :ghissue:`3547`: Don't use deprecated numpy APIs
* :ghissue:`2092`: Move to new Numpy API
* :ghissue:`3601`: matplotlib.style.available not updated upon adding/deleting .mplstyle files
* :ghissue:`3616`: matplotlib.pyplot.imread silently fails on uint16 images.
* :ghissue:`3628`: Document auto-init behavior of colors.Normalize and cm.ScalarMappable.
* :ghissue:`3640`: figure.max_num_figures was renamed to figure.max_open_warning.
* :ghissue:`3650`: Typo fixes. [backport to doc branch]
* :ghissue:`3651`: Error when saving rasterized figure to PDF
* :ghissue:`3470`: MacOSX backend breaks for matplotlib 1.4 after importing seaborn
* :ghissue:`3564`: Rcparam validation fix
* :ghissue:`3642`: TST : know-fail shadding tests
* :ghissue:`3641`: Annotations with Latex code cause errors in 1.5 master
* :ghissue:`3623`: Qt5 backend doesn't work with Qt 5.3
* :ghissue:`3636`: mp4 is a container format, not a codec
* :ghissue:`3632`: Fix for #3623
* :ghissue:`3639`: Shading tests failing on master
* :ghissue:`3619`: PatchCollection: pass other kwargs for match_original=True
* :ghissue:`3617`: PatchCollection.__init__ ignores all kwargs if match_original=True
* :ghissue:`3637`: typo: mp4 -> mpeg4. Closes #3636.
* :ghissue:`3629`: examples: fix pep8 error class E211
* :ghissue:`2873`: Add violin plots
* :ghissue:`3622`: setup.py creates a zombie C extension called "freetype2"
* :ghissue:`3213`: add whats_new entry for nbagg
* :ghissue:`3392`: Cannot pickle `figure` or `axes` (TypeError: instancemethod)
* :ghissue:`3614`: Pickling imshow fails (?due to _imcache)
* :ghissue:`3606`: nbagg issues with ipython 3.0
* :ghissue:`3494`: corrupt eps output on python3
* :ghissue:`3627`: Fixed Image and Renderer pickling
* :ghissue:`3515`: examples: fix pep8 error classes E111 and E113
* :ghissue:`3625`: animate_decay.py example code is less complicated
* :ghissue:`3621`: matplotlib.__version__ is now unicode as of 1.4.0
* :ghissue:`3505`: Interactive mode not working in 1.4
* :ghissue:`3620`: Revert interactive determination
* :ghissue:`3311`: Ship conda package metadata with matplotlib?
* :ghissue:`3248`: Divide by zero error in matplotlib.tests.test_colors.test_light_source_shading_color_range
* :ghissue:`3613`: Fix problem with legend if data has NaN's [backport to 1.4.x]
* :ghissue:`3618`: UnicodeDecodeError when I try to import matplotlib from directory with non-ascii name
* :ghissue:`3313`: BUG: 3 fixes for widgets (MultiCrusor, SpanSelector, Slider)
* :ghissue:`3496`: BUG : fix str vs bytes issue in py3 in ps backend
* :ghissue:`3609`: Nbagg icons
* :ghissue:`3611`: Fix spelling error
* :ghissue:`3607`: Icon for font awesome 3.2.1 and 4 [backport to 1.4.x]
* :ghissue:`3605`: matplotlib.pylab.specgram generate bad image in 1.4.0
* :ghissue:`3604`: regression in pandas test suite with mpl 1.4.0
* :ghissue:`3603`: Error saving file (Qt5 backend)
* :ghissue:`2907`: Expose ax.yaxis.labelpad and ax.xaxis.labelpad to the rc file
* :ghissue:`3096`: Axes labelpad rc
* :ghissue:`3544`: flier objects missing from structure return by boxplot
* :ghissue:`3600`: BUG: now only set 'marker' and 'color' attribute of fliers in boxplots
* :ghissue:`3599`: BUG: now only set 'marker' and 'color' attribute of fliers in boxplots
* :ghissue:`3516`: import error when non-ascii characters are present in cwd or user name (windows)
* :ghissue:`3560`: Updated whats new for nbagg and legend/patheffects docs.
* :ghissue:`3594`: Unicode decode error [backport to 1.4.x]
* :ghissue:`3532`: BUG : skip looking up expanduser if unicode error
* :ghissue:`3574`: `rotation` parameter has no effect on `RegularPolyCollection`
* :ghissue:`3409`: Win fixes
* :ghissue:`3573`: Bug: Empty sym string for boxplots still displays fliers.
* :ghissue:`3595`: Some small doc fixes only relevant on the master branch
* :ghissue:`3291`: Lightsource enhancements
* :ghissue:`3459`: boxplot in version 1.4.0 does not respect property settings for fliers (flierprops)
* :ghissue:`3592`: Fix crash in picking for zero-length path collection
* :ghissue:`3590`: Won't use a font although it can be found by the FontManager
* :ghissue:`3591`: BUG: Cannot pick empty vline
* :ghissue:`3586`: Merge V1.4.x into master. 
* :ghissue:`3585`: merge V1.4.0-doc into v1.4.x 
* :ghissue:`3412`: Matplotlib 1.4 doesn't install from source on CentOS 6
* :ghissue:`3423`: Pytz should be specified and documented as a required dependency
* :ghissue:`3569`: boxplot stats regression on empty data
* :ghissue:`3563`: boxplot() and xticklabels
* :ghissue:`3566`: BUG : don't assume label in boxpplot_stat
* :ghissue:`3567`: Fixed the differencing of images for the webagg/nbagg backends.
* :ghissue:`3571`: BUG : deal with empty list passed to boxplot
* :ghissue:`3533`: BUG : fix handling of flierprop by boxplot
* :ghissue:`3581`: pep8 cleanup on scatter_demo.py
* :ghissue:`3514`: Ticks on top axis disappear if tick size is too large (when using bbox_inches='tight')
* :ghissue:`3578`: Fixes test to assert instead of print
* :ghissue:`1713`: Can't store Unicode values in .matplotlibrc
* :ghissue:`3575`: Supports locale-specified encoding for rcfile.
* :ghissue:`3479`: Build dep updates
* :ghissue:`233`: Make hist with 'step' histtype draw Line2D instead of Patch
* :ghissue:`3522`: Inverting a datetime / plot_date y-axis
* :ghissue:`3570`: matplotlib save dynamic user changes to plot
* :ghissue:`3568`: Daily build fails at "import matplotlib.pyplot as plt"
* :ghissue:`3541`: pyplot: Fix exception in `_backend_selection` during import [backport to 1.4.x]
* :ghissue:`3565`: clabel randomly inconsistend when placed manually
* :ghissue:`3552`: Nbagg enhancements
* :ghissue:`3559`: Install texlive and other dependencies when building docs.
* :ghissue:`3550`: Install texlive when building docs.
* :ghissue:`3555`: Typo in comment documentation for example timers.py
* :ghissue:`3556`: copy/paste corrections in test_backend_qt5
* :ghissue:`3545`: Provide an informative error message if something goes wrong in setfont [backport to 1.4.x]
* :ghissue:`3551`: Window isn't drawn
* :ghissue:`3538`: Importing matplotlib failing when pacakge "six" is 1.3.0
* :ghissue:`3542`: fix boxplot docs
* :ghissue:`3548`: Silence some Sphinx warnings by rewriting docstrings.
* :ghissue:`3549`: Texlive travis
* :ghissue:`3539`: DEP : update six minimum version
* :ghissue:`3543`: DOC : fix main-page tags
* :ghissue:`3524`: Bug in AutoDateLocator when dates are in reverse order
* :ghissue:`3455`: Documentation bug: boxplot docs have contradicting information
* :ghissue:`3468`: boxplot() draws (min, max) whiskers after a zero-IQR input regardless of whis value
* :ghissue:`3436`: matplotlib.use('nbagg ') does not work in Python 3
* :ghissue:`3464`: BUG : nbagg py3k compatibility
* :ghissue:`3534`: BUG : fixes whis over-writing in boxplot_stats
* :ghissue:`3529`: Symlog norm still gives wrong result with integer lintresh.
* :ghissue:`3535`: BUG/DOC : Correct default value listed in docstring
* :ghissue:`3537`: 3D figures cannot be created in 1.4.0: 'module' object has no attribute '_string_to_bool'
* :ghissue:`3369`: Added legend.framealpha to rcParams, as mentioned in axes.legend docstring
* :ghissue:`3510`: Fix setupext [backport to 1.4.x]
* :ghissue:`3530`: Only insert links to pdfs if we are actually generating these.
* :ghissue:`3487`: Can not import matplotlib when launching from non-ascii path 
* :ghissue:`3527`: Drawing an arrow using axis.annotate raises DeprecationWarning
* :ghissue:`3525`: BUG : decode byte-strings in afm.py
* :ghissue:`3523`: invalid EPS figure in Mac OS X
* :ghissue:`3526`: BUG : fix eps corruption when using clipping
* :ghissue:`3492`: Allow python 3 version of PyCXX
* :ghissue:`3521`: More doc fixes
* :ghissue:`3504`: postscript axes corner is not perfect
* :ghissue:`3520`: a question about subplot in spyder
* :ghissue:`3513`: examples: fully automated fixing of E30 pep8 errors
* :ghissue:`3512`: What else apart from `useOffset` is controlling tick label offsets?
* :ghissue:`3461`: This fixes a bunch of Sphinx warnings
* :ghissue:`3507`: general pep8 fixes 
* :ghissue:`3506`: Named colors example, figure size correction [backport to 1.4.0-doc]
* :ghissue:`3493`: Incorrect use of super() in mplot3d?
* :ghissue:`3439`: Registering backends broken by backwards incompatible change
* :ghissue:`3511`: Error in plot-gui while saving image
* :ghissue:`3509`: Add Build Instructions for Windows 7 Using Visual Studio?
* :ghissue:`3503`: Win fix simple
* :ghissue:`3495`: BUG : don't use super(self.__class__, self)
* :ghissue:`3500`: Annotation xytext property does not return xyann value
* :ghissue:`3501`: Bugfix for text.xytext property
* :ghissue:`3376`: Move widget.{get,set}_active to AxisWidget.
* :ghissue:`3497`: Ortho basemap projection with limits crashes
* :ghissue:`3447`: cursor doesn't change on keypress (GTKAgg backend)
* :ghissue:`3419`: Better repr for Bboxes.
* :ghissue:`3474`: call set cursor on zoom/pan toggle [backpont to 1.4.x]
* :ghissue:`3425`: Pep8ify examples
* :ghissue:`3477`: Better check for required dependency libpng
* :ghissue:`3472`: Memory leak displaying PIL image.
* :ghissue:`3484`: TclError for draw_event handler calling close()
* :ghissue:`3480`: Duplicate labels produced when using custom Locators/Formatters
* :ghissue:`3475`: need for rubberband in zoom tool
* :ghissue:`3478`: BUG : restore back-compatibility of regisiter_backend
* :ghissue:`3471`: Fix for invalid check of freetype version when no freetype library exists [backport to 1.4.x]
* :ghissue:`2900`: Remove no-longer-necessary KnownFail for python 3.2.
* :ghissue:`3465`: psd() draw a wrong line with sliced array(Matplotlib 1.4.0)
* :ghissue:`3454`: backend_qt5 (1.4.0): Not saving the figure with NavigationToolbar (solved)
* :ghissue:`3467`: Bugfix in mlab for strided views of np.arrays [backport to 1.4.x]
* :ghissue:`3469`: Fix handling of getSaveFileName to be consistent [backport to 1.4.x]
* :ghissue:`3416`: Specify difficulties installing mpl on OSX.
* :ghissue:`2970`: add test of all the standard marker symbols
* :ghissue:`3318`: Running `setup.py egg_info` starts to compile everything
* :ghissue:`3384`: Test marker styles
* :ghissue:`3466`: Invalid DISPLAY variable
* :ghissue:`3463`: when executing a small script nothing happens!!
* :ghissue:`3462`: Add legend.framealpha to matplotlibrc
* :ghissue:`2934`: Line labels don't update in the legend after changing them through the Qt4Agg dialog box
* :ghissue:`3431`: Qt5 toolbar support not working in release 1.4.0
* :ghissue:`3407`: Update dns/IP adress
* :ghissue:`3456`: DOC : add known-bug + fix for QT5 toolbar issue
* :ghissue:`3458`: DOC : minor import tweaks
* :ghissue:`3460`: zoomed_inset_axes shows a incorrect result.
* :ghissue:`3457`: Add Qt5Agg to backends in matplotlibrc.template.
* :ghissue:`3417`: update citation page
* :ghissue:`3450`: Wrong permissions when installing from source on Linux
* :ghissue:`3422`: Use mailmap in github stats
* :ghissue:`3429`: DOC : added pytz to optional dependencies docs
* :ghissue:`3434`: Update tight_bbox.py [backport to 1.4.x]
* :ghissue:`3453`: Bbox rebase 14
* :ghissue:`3452`: Bbox fix rebase
* :ghissue:`3449`: matplotlib/colors.py: modifying dict while iterating
* :ghissue:`3445`: can't bring plot to front eclipse after running the script on mac ox 10.9
* :ghissue:`3427`: DOC : added DOI link to citing.html
* :ghissue:`3443`: Pip install matplotlib does not work on Python 3.2 anymore
* :ghissue:`3440`: V1.4.x (Mac backend's "Save as ...")
* :ghissue:`3438`: Get rid of unused pre python 2.6 code in doc make.py
* :ghissue:`3414`: Fixes TypeError when installing without freetype
* :ghissue:`2931`: Added center and frame arguments for pie-charts
* :ghissue:`3411`: fix rst mark up
* :ghissue:`3413`: update freetype version in docs
* :ghissue:`3428`: DOC : add caveat about freetype 2.3
* :ghissue:`3430`: DOC : fixed markup / boxplot text in whats_new
* :ghissue:`3426`: DOC : remove piwik code
* :ghissue:`3432`: Update whats_new.rst
* :ghissue:`3396`: Sort out OSX dmg files
* :ghissue:`2803`: Get wx backends and examples compitable with Phoenix
* :ghissue:`3415`: DOC: fix markup and download link in the Windows install section
* :ghissue:`3410`: Latex rendering fails in ipython
* :ghissue:`3408`: test_text Modify filter warning regex
* :ghissue:`3404`: Wrong plot on basemap with `latlon=True` 
* :ghissue:`3406`: A layer stacking problem of exported svg image compatible with inkscape
* :ghissue:`3282`: Catch warning thrown in Mollweide projection.
* :ghissue:`2635`: Crash on saving figure if text.usetex is True
* :ghissue:`3327`: FontProperties are shared by all three titles of an Axes object
* :ghissue:`3328`: copy FontProperty objects when creating titles (fix #3327)
* :ghissue:`3241`: Cast to integer to get rid of numpy warning
* :ghissue:`3335`: Fix and new test for #3327
* :ghissue:`3278`: Use libpng-config if available
* :ghissue:`3244`: Filter warnings in rcparams test (and others)
* :ghissue:`1980`: Custom marker created from vertex list scales wrong
* :ghissue:`3378`: BUG: Fixes custom path marker sizing for issue #1980
* :ghissue:`3395`: Update Downloads page
* :ghissue:`2545`: Some of Russian letters are not visible in EPS
* :ghissue:`3405`: The memory taken up from the RAM pool by imshow
* :ghissue:`1717`: Definitive docs for how to compile on Windows
* :ghissue:`3401`: enlarge on windows build instructions slightly
* :ghissue:`3398`: windows build comments with winbuild repository link
* :ghissue:`3399`: Cherrypick doc changes to v1.4.0
* :ghissue:`3397`: Install guide tweaks
* :ghissue:`2999`: Update and clarify installation documentation
* :ghissue:`3394`: DOC : add note about np.matrix and pandas objects
* :ghissue:`2138`: pyplot.scatter not converting *x* and *y* to a 1-D sequence when the input is a 1xN matrix...
* :ghissue:`3388`: Build support with dependencies for Windows
* :ghissue:`3144`: Backend documentation
* :ghissue:`3379`: syntax warning in qt5 with 1.4.0rc4
* :ghissue:`2451`: _macosx.so crash in build using Xcode 5
* :ghissue:`3362`: 3D line object loses its color cycle in a function animation
* :ghissue:`3390`: Move stylelib directory to mpl-data
* :ghissue:`3385`: Regression with cx_support in 1.4.0rc4
* :ghissue:`3389`: request: more than two axes/spine on plot
* :ghissue:`3386`: add PySide to interactive_bk list
* :ghissue:`3383`: Tkinter backend finishes with segmentation fault
* :ghissue:`3289`: Float division patches
* :ghissue:`2881`: Focus stays in terminal on OS X and 1.3.1
* :ghissue:`3381`: BUG : make qApp global before using it
* :ghissue:`2060`: Fix tox.ini
* :ghissue:`3380`: Remove residual mention of TODO file, which no longer exists.
* :ghissue:`166`: RuntimeError: CGContextRef is NULL with draw_artist
* :ghissue:`169`: csv2rec encoding support
* :ghissue:`311`: Intelligent log labels
* :ghissue:`374`: Add general rcParam mechanism for text
* :ghissue:`449`: stem plots have no color cycling mechanisms
* :ghissue:`862`: The y-axis label of figures created with psd() should not say "Density" when scale_by_freq=False
* :ghissue:`1021`: Hatching Inconsistencies
* :ghissue:`1501`: Panning and zooming does not work on axes created with twinx (and twiny)
* :ghissue:`1412`: Path collection filling/stroking logic is different from the usual in the pdf backend
* :ghissue:`1746`: pcolormesh with lambert projection ignores lower hemisphere
* :ghissue:`2684`: Savefig to EPS with cyrillic title doesn't work
* :ghissue:`1933`: backend_pdf.py fails on 3d plots (1.3.x)
* :ghissue:`1996`: Bug when installing in OS X with easy_install
* :ghissue:`2157`: numpy/core/_methods.py:57: RuntimeWarning: invalid value encountered in double_scalars
* :ghissue:`2292`: Axes label rotation
* :ghissue:`2343`: Test failures
* :ghissue:`2448`: idle_add deprecation warning.
* :ghissue:`2355`: Type Error in bar3d plot when saved as svg
* :ghissue:`2361`: pylab import fails for non-framework python installs on OS X
* :ghissue:`3349`: DOC : added folders for api_changes and whats_new
* :ghissue:`2596`: Latex formatting does not seem to work with xkcd style
* :ghissue:`2611`: no __init__.py in matplotlib-1.3.1.win-amd64-py2.7.exe
* :ghissue:`2620`: WebAgg for multiple clients
* :ghissue:`2686`: Tornado error when using matplotlib WabAgg backend
* :ghissue:`2649`: incorrect detection of text.latex.unicode=True
* :ghissue:`3367`: macosx broken on python 3.4 non-framework builds, shaky on framework
* :ghissue:`3360`: BUG : modified logic on starting qApp
* :ghissue:`3372`: DOC: Fixed the wording of the deprecation warning
* :ghissue:`3363`: Identification of freetype when 'freetype-config --ftversion' fails.
* :ghissue:`3366`: feature request: set_data method for errorbar
* :ghissue:`3365`: font configuration
* :ghissue:`3361`: saving 3D line figure in pgf format results in error
* :ghissue:`3359`: PEP8 conformity; removed outcommented code
* :ghissue:`3358`: Don't use unicode_literals in backend_qt4
* :ghissue:`3357`: backend_qt5.py Don't use six.u
* :ghissue:`3340`: Plotting a dataframe from pandas: IndexError: list index out of range
* :ghissue:`3183`: pep8ify examples/ part 3
* :ghissue:`3338`: resizing figures in webagg
* :ghissue:`3353`: Fix typo reported by @cel4
* :ghissue:`3240`: Add documentation to Travis builds.
* :ghissue:`3287`: DOC: comprehensive rewrite for OSX binary install
* :ghissue:`3348`: fix deprecation warning in simple linear interpolation
* :ghissue:`3336`: Boxplot shows wrong color for lower outliers
* :ghissue:`3337`: BUG : don't assign color to flier props if None
* :ghissue:`3245`: First pass at the reorganization of content on the matplotlib home page.
* :ghissue:`3342`: AGG link changed. Also fix other doc warnings
* :ghissue:`3262`: 1.4.0 RC1: --ftversion vs --version freetype version
* :ghissue:`3214`: add whats_new for webagg
* :ghissue:`3209`: Install docs are hopelessly out of date
* :ghissue:`3322`: Fixed error with QSizePolicy
* :ghissue:`3308`: SVG backend font-weight bug
* :ghissue:`3344`:  Cairo backend math text
* :ghissue:`3339`: Fix mathmpl images not showing in HTML Help (CHM)
* :ghissue:`3333`: No response on editing axes by NavigationToolbar2 in interactive mode
* :ghissue:`3332`: savefig crashes in backend_p[df|s].py when using plot-option mew
* :ghissue:`3331`: Restore compatibility with Python 3.2
* :ghissue:`3304`: 1.4.0 RC1+7: *** glibc detected *** python: corrupted double-linked list
* :ghissue:`3324`: Fix #3304.
* :ghissue:`3325`: ENH: add HTML Help builder option
* :ghissue:`3326`: Docs build failure on Launchpad.
* :ghissue:`3329`: Workaround for Sphinx not escaping ``_`` (underscore) for tex output
* :ghissue:`3323`: Replaced unicode() function by six.text_type
* :ghissue:`3321`: SymLogNorm returns 'inf' and 'nan' when given negative vmin as __init__ argument
* :ghissue:`3223`: get colorbar slides
* :ghissue:`3259`: Attribute error when testing on system without ghostscript
* :ghissue:`3301`: Colormap choice guidelines in documentation - based on talk at SciPy 2014
* :ghissue:`3320`: DOC: Fix Malformed table. Text in column margin
* :ghissue:`3319`: colorbar 
* :ghissue:`3317`: TST: Fix test_animation RuntimeErrors on Windows
* :ghissue:`3297`: test_mplot3d.test_quiver3d tests require np.meshgrid from numpy >= 1.7.0
* :ghissue:`3310`: Fix MatplotlibDeprecationWarning: The "loc" positional argument to legend is deprecated
* :ghissue:`3312`: BUG: fix test error when ghostscript not installed
* :ghissue:`3299`: 1.4.0 RC1 UserWarning: Rasterization of PolyCollection will be ignored
* :ghissue:`3307`: SVG backend font-weight bug
* :ghissue:`3306`: BUG : restore allow_rasterization on PolyCollection
* :ghissue:`3302`: Check for GhostScript in this test which needs it
* :ghissue:`3194`: Annotate bbox darrow
* :ghissue:`3277`: MNT : better error handling on determining gs version
* :ghissue:`3300`: Quiver3d fixes
* :ghissue:`3284`: BUG : fix  _reshape_2D bug with [(n, 1), ..] input
* :ghissue:`3220`: pylab_examples/boxplot_demo.py crashes
* :ghissue:`3296`: V1.4.x
* :ghissue:`3295`: Use the interpolation parameter in make_thumbnail
* :ghissue:`3288`: put generated .aux file into .gitignore
* :ghissue:`3283`: Suppress invalid argument warnings in inverse Mollweide projection
* :ghissue:`3280`: Docs build failure on Launchpad.
* :ghissue:`3235`: Silence some more warnings
* :ghissue:`3281`: Error with pip install with Python 3.4
* :ghissue:`3252`: ImportError: No module named 'mpl_toolkits'
* :ghissue:`3264`: 1.4.0rc1: Python-level memory "leak" (internal font cache?)
* :ghissue:`3274`: BUG : fixes FontProperties memory leak
* :ghissue:`3275`: TST: Fix ImportError: No module named 'mpl_toolkits'
* :ghissue:`3276`: free type memory leak
* :ghissue:`3250`: Fix WindowsError: [Error 32] The process cannot access the file
* :ghissue:`2918`: re-write contribution guide lines
* :ghissue:`3170`: DOC : whole bunch of documentation clean up
* :ghissue:`3115`: do not reccomened using pyplot in scripts
* :ghissue:`3271`: Fix use of a non-integer index in split_path_inout.
* :ghissue:`3247`: Usage faq
* :ghissue:`3255`: Out of memory failures on Travis
* :ghissue:`3268`: Travis broken
* :ghissue:`3270`: DOC : windows install docs from cgohlke
* :ghissue:`3257`: MRG: refactor and bugfixes for plot_directive
* :ghissue:`3238`: OSX install
* :ghissue:`3258`: Fix various memory leaks discovered through valgrind
* :ghissue:`2908`: 404 links on the screenshot page
* :ghissue:`3253`: Stop make.py removing generated documentation figs
* :ghissue:`3269`: Upload artifacts only on main repository.
* :ghissue:`3251`: Add animation.convert_path setting to matplotlibrc.template
* :ghissue:`3266`: remove obsolete TODO files
* :ghissue:`3261`: Get rid of warning about GTK3Agg with python3
* :ghissue:`3260`: webagg backend does not show figures due to JS error
* :ghissue:`3256`: Fix memory leak in FT2Font.
* :ghissue:`3249`: TST: Fix test_backend_ps failures on Windows
* :ghissue:`3254`: Won't write \approx LaTeX character in legend?
* :ghissue:`3234`: Put PEP8 tests in its own Travis configuration
* :ghissue:`3217`: Added some function arguments to the documentation for FuncAnimation
* :ghissue:`3243`: Fixed backend workflow.
* :ghissue:`3246`: Fix some hyperlinks in the documentation
* :ghissue:`3004`: FAQ and unit/ still refers to nxutils
* :ghissue:`2758`: Test toolkits rebase
* :ghissue:`2533`: Bug in mplot3D with PolyCollection: (0, 0) data point is always inserted into the data set.
* :ghissue:`2045`: PolyCollection path closing is projected incorrectly by add_collection3d
* :ghissue:`2928`: matplotlib.sphinxext.plot_directive.py issue with ..image:: directive option passing for latex output. 
* :ghissue:`2975`: webagg generated JS quotes
* :ghissue:`3198`: Fix deprecation warning in simple_linear_interpolation
* :ghissue:`3152`: OSX test failures
* :ghissue:`3175`: Navigation toolbar, Save button, last used folder path
* :ghissue:`3197`: Memory Leak in Agg
* :ghissue:`3239`: Fix auto-closing in PolyCollection
* :ghissue:`3193`: Fix plot directive when used with multiple options.
* :ghissue:`3236`: Test PEP8 stuff in separate Travis build.
* :ghissue:`3188`: Np error patch
* :ghissue:`3186`: Numpy 1.9 issues.
* :ghissue:`3154`: whitelist mpl_toolkits tests
* :ghissue:`3230`: DOC : added note about useoffset rcparam
* :ghissue:`3216`: edit useoffset docs in ticker to mention rcparam
* :ghissue:`3228`: DOC : top_level doc-string clean up
* :ghissue:`3190`: Adding two new styles to mplstyles
* :ghissue:`3215`: Close files in animation to silence some warning in the test suite on python3 
* :ghissue:`3237`: Fix Collection3D. Fixes legend for scatter3d
* :ghissue:`3233`: Update numpy version in setup.py
* :ghissue:`3227`: Whats new cleaning
* :ghissue:`3224`: Fix lots of warnings in docs/Examples that crash
* :ghissue:`3229`: DEP : bump min numpy to 1.6
* :ghissue:`3226`: bump numpy version to 1.6
* :ghissue:`3191`: Test errors with numpy 1.5 - advice?
* :ghissue:`3222`: add reduce to the list of imports from six.moves
* :ghissue:`3126`: insertion of Annotation class docs into annotate docstring broken
* :ghissue:`3221`: Fixes #3219 by ignoring pep8 noncomplicant auto-generated file.
* :ghissue:`3219`: pep8 test failure on macosx
* :ghissue:`1541`: Transparecy of figures in 3D plots (mplot3d)
* :ghissue:`2227`: Refactor of top-level doc/README.rst
* :ghissue:`3211`: Mplot3d/depthshade
* :ghissue:`1692`: switch to turn off auto-shading in scatter3D
* :ghissue:`3218`: Started simple reorganization of the gallery examples
* :ghissue:`2487`: WebAgg kills IPython kernel
* :ghissue:`3184`: DOC : added warning to doc of get_window_extent
* :ghissue:`3055`: Add warning to `get_window_extent`
* :ghissue:`3165`: Bug restore boxplot defaults
* :ghissue:`3042`: boxplot does not take parameters into account
* :ghissue:`3207`: Fix memory leak in tostring_rgba_minimize(). (#3197)
* :ghissue:`3210`: Fix PEP8 error.
* :ghissue:`3203`: Make type1font.py work better on Python 3.x
* :ghissue:`3049`: PDF Embedded fonts with python3 mpl reported as 'Unknown' by pdffonts and pdf readers
* :ghissue:`3155`: BUG : fix fetch of freetype version during build
* :ghissue:`3192`: TST : drop 3.2, add 3.4
* :ghissue:`3090`: Set up travis to test 3.4/drop 3.2
* :ghissue:`3121`: Added 'PyQt4v2' to valid values for backend.qt4
* :ghissue:`2977`: RC backend.qt validation too limiting.
* :ghissue:`3167`: BUG : raise exception in subplot if num out of range
* :ghissue:`3166`: subplot(x, x, 0) should raise Exception
* :ghissue:`3208`: Add missing import of unichr from six.
* :ghissue:`3156`: DOC : added whats_new entry for Qt5 backend
* :ghissue:`2475`: BUG: manual clabel positioning broke between 1.2 and 1.3
* :ghissue:`2843`: BUGFIX:  This change fixes #2475, where contour labels added manually
* :ghissue:`3205`: BUG : patch from mikofski to fix webagg example
* :ghissue:`3204`: embedded_webagg.py example needs patches
* :ghissue:`3202`: dateutil isn't included in 1.3.1
* :ghissue:`3199`: triplot, etc examples broken by merged PR #3182
* :ghissue:`3201`: Revert "[examples/api] autopep8 + use np.radians/np.degree where appropr...
* :ghissue:`3200`: Revert "pep8ify more examples in examples/ + use np.radians/np.degrees"
* :ghissue:`3174`: MNT : replace and deprecated qt4_compat
* :ghissue:`3172`: replace qt4_compat.py
* :ghissue:`3112`: BUG : patches.Wedge.set_radius set wrong attribute
* :ghissue:`2952`: BUG : turned clipping off on pie chart components
* :ghissue:`2518`: pie chart is trimmed
* :ghissue:`2951`: BUG/API : tweaked how AnchoredSizeBar handles font properties
* :ghissue:`2394`: AnchoredSizeBar does not respect FontProperties size setting.
* :ghissue:`3157`: BLD : fix build on windows
* :ghissue:`3140`: Building issue under windows.
* :ghissue:`3189`: BUG: use unittest.mock for Python 3.3+
* :ghissue:`3045`: Use less aggressive garbage collection
* :ghissue:`3044`: matplotlib shouldn't call gc.collect()
* :ghissue:`3185`: DOC : added details about r/cstride in plot3d
* :ghissue:`3143`: Document r/c stride in plot_surface/wire frame
* :ghissue:`3182`: pep8ify more examples in examples/ + use np.radians/np.degrees
* :ghissue:`3181`: [examples/api] autopep8 + use np.radians/np.degree where appropriate
* :ghissue:`3163`: DOC : documented bottom kwarg of hist
* :ghissue:`3136`: bottom keyword argument of hist() not documented
* :ghissue:`3180`: DOC: Fix order of parameters in ax.text docstring.
* :ghissue:`3178`: Regression in IPython Sphinx extension
* :ghissue:`3176`: rendering bugs in log/log-base-2 histograms
* :ghissue:`3168`: DOC : add prominent doc about set_useOffset
* :ghissue:`2796`: pyplot.plot casts integer tick values to floats
* :ghissue:`3171`: Changing the legend fontsize "hides" dotted lines in the legend
* :ghissue:`3162`: BLD : made tornado an optional external package
* :ghissue:`3039`: tornado not optional
* :ghissue:`3169`: Update pyplot_tutorial.rst
* :ghissue:`1026`: Feature request: Quiver plot in Axes3D object
* :ghissue:`2268`: _update_patch_transform(): AttributeError: 'Rectangle' object has no attribute '_y'
* :ghissue:`3084`: Improving plt.hist documentation
* :ghissue:`1847`: Crash when creating polar plot with log scale on radial axis
* :ghissue:`3160`: Glade tutorial branch fixed
* :ghissue:`3008`: Nbagg backend
* :ghissue:`3066`: BUG: restore default boxplot style and respect for the sym kwarg
* :ghissue:`3164`: fix bad pathing in whats_new.rst
* :ghissue:`3161`: Docs build failure
* :ghissue:`3088`: Add tutorial file for Glade 3.16-GTK3.10-Python 3
* :ghissue:`3159`: BUG : fix qt4 backends
* :ghissue:`3158`: backend_pgf: Error message for missing latex executable (fix #3051)
* :ghissue:`3051`: improve error message when pgf can't find tex executable
* :ghissue:`3125`: DOC : added annotation example to arrow docstring
* :ghissue:`2350`: Arrows affected by data transform
* :ghissue:`3149`: 3dquiver rebranch
* :ghissue:`2961`: Implementation of 3D quiver
* :ghissue:`3141`: BUG: Fix 'TypeError: expected bytes, str found' on Python 3
* :ghissue:`3072`: Implement backend for PyQt5 + modify Qt4 backends to use Qt5 module via shim
* :ghissue:`3153`: Avoid floating point sensitivity in trisurf3d test
* :ghissue:`3151`: document api changes
* :ghissue:`3139`: savefig() saves different aspect ratio than show()
* :ghissue:`3138`: ENH: Function to "reset" the color cycle on a set of axes
* :ghissue:`3145`: Error in subplots sharey docs?
* :ghissue:`3147`: Fix doc for sharey keyword in pyplot.subplots.
* :ghissue:`2958`: feature request: set figure sizes w.r.t. screen resolution
* :ghissue:`3082`: GTK-Glade tutorial is out of date
* :ghissue:`3133`: Doc cleanup
* :ghissue:`3110`: BUG: Add Figure.delcolorbar() to fully delete a colorbar
* :ghissue:`2688`: Deleting axis in matplotlib > v1.2.1 does not work similar to v1.1.1
* :ghissue:`3131`: DOC : sixify unichr
* :ghissue:`3117`: Qt4 backend using unichr() in python3
* :ghissue:`3132`: DOC : added note about maintain ref to widgets
* :ghissue:`3105`: Sliders unresponsive when created inside a function
* :ghissue:`2927`: BUG : don't use mutable objects as dictionary keys
* :ghissue:`2828`: PS backend fails to save polar plot
* :ghissue:`3122`: DOC: mention Anaconda; clean some old junk out of the FAQ
* :ghissue:`3130`: Scatter set sizes whats new
* :ghissue:`3113`: BUG: PathCollection' object has no attribute 'set_sizes'
* :ghissue:`3127`: DOC : added inherited-members to Axes autodoc
* :ghissue:`3128`: Axes aspect doc
* :ghissue:`2608`: Docs: pyplot.axes() should mention the `aspect` keyword argument
* :ghissue:`3103`: errorbar: fmt kwarg defaults to None; use 'none' to suppress plot call
* :ghissue:`2366`: Errorbar plot ignores linestyle rcParam
* :ghissue:`3123`: DOC : add documentation to Polygon methods
* :ghissue:`3035`: Add docs to Polygon `*_xy`
* :ghissue:`3124`: Zooming to a point changes a picked point's index for data longer than 100 points
* :ghissue:`3120`: typo fix
* :ghissue:`2492`: subplots() shared scale is off
* :ghissue:`3118`: Wrong datalims with empty plots with shared axes
* :ghissue:`2963`: Segmentation Fault on adding BBoxImage to matshow
* :ghissue:`3099`: New animation example (Joy Division's Unchained Love cover)
* :ghissue:`3111`: bug fix: check the type of the 'key' of the two array 'r1' and 'r2'
* :ghissue:`3093`: Python 3.4 tkagg backend error while importing pyplot
* :ghissue:`3108`: DOC : clarified doc of add_artist
* :ghissue:`3109`: Undesired crop with thick lines
* :ghissue:`2822`: DOC : added caveat to Axes.add_artist
* :ghissue:`2288`: Symmetric Log scale: linscale < 1 ?
* :ghissue:`3106`: small bug in 'class Appender'
* :ghissue:`3107`: Bug-fix for issue 3106
* :ghissue:`3079`: Scatter plot color array length should raise Error
* :ghissue:`3092`: Adds check that rgb sequence is of length 3
* :ghissue:`3100`: Use autolim kwarg in add_collection to prevent duplication of effort.
* :ghissue:`3095`: Memory issue when plotting large arrays with pcolormesh
* :ghissue:`2738`: BUG : errorbar does not respect `lines.linestyle` rcparam
* :ghissue:`3104`: BUG: in Spine.set_position(), preserve most Axis info.
* :ghissue:`2941`: Order of ax.spines[].set_position() and ax.yaxis.set_major_formatter() produces different results
* :ghissue:`3012`: set_ticks_position to non-default position, sets all tick texts to empty string
* :ghissue:`3097`: scatter should take array for alpha
* :ghissue:`3101`: Streamplot: clean up handling of masks, eliminate warning in test.
* :ghissue:`3102`: Image: handle images with zero columns or rows.
* :ghissue:`3091`: set_xlim() crashes kernel if interpolation='none'
* :ghissue:`3098`: Fix regression in pcolormesh: don't generate a path list.
* :ghissue:`3094`: Various improvements in finance.py
* :ghissue:`2929`: clip_on documentation note/warning
* :ghissue:`3029`: freetype cannot be found by build
* :ghissue:`3032`: Fix unable to find Freefont on Ubuntu 14.04
* :ghissue:`3067`: Fix for bug #3029.
* :ghissue:`3052`: Unresponsive figure when using interactive mode on Windows
* :ghissue:`3078`: fix argument checks in axis/base.margins
* :ghissue:`3086`: Multiple test errors in current master on Python 3.4 / Ubuntu 12.04
* :ghissue:`2945`: Bug in y-minimum for weighted, log, stepped `Axes.hist`
* :ghissue:`3089`: Fix log hist y-axis minimum with weighted data
* :ghissue:`3087`: small error in comment
* :ghissue:`2996`: Violin Plots
* :ghissue:`3053`: symlog-scale: Remove asssert linscale >= 1.
* :ghissue:`3085`: Mistake in documentation of Figure.colorbar()
* :ghissue:`3077`: Invalidate font manager when rcParam family lists change.
* :ghissue:`3081`: Points to pixels
* :ghissue:`2889`: bug: path effects in text() change text properties
* :ghissue:`3080`: Minor fix to commit 24bc071
* :ghissue:`3054`: BUG : fix for text path rendering issues
* :ghissue:`3075`: Add warning about updating font rcparams
* :ghissue:`3076`: Bug: backend_pdf: UnicodeDecodeError: 'ascii' codec can't decode byte 0xe2
* :ghissue:`3074`: TST : force re-building of font-cache
* :ghissue:`3065`: font priority bug
* :ghissue:`3073`: TST : fix font-priority test
* :ghissue:`3047`: Updated CHANGELOG and whats_new.rst: with (re-)generate auto-legend
* :ghissue:`2150`: Bug in bar plot, leading zeros in data (bar heights) are ignored.
* :ghissue:`2942`: #2150 Updating patch limits if either width or height is non zero: Issue 2150
* :ghissue:`2541`: mouse-over coordinates wrong for polar plot with customized theta direction/offset
* :ghissue:`2874`: Fix for issue #2541 (revised)
* :ghissue:`1981`: plot() - Markevery only supports startpoint and stepsize, not endpoint
* :ghissue:`2662`: allow slice and fancy indexing to only show some markers 
* :ghissue:`2855`: ENH Added the origin option to `spy`
* :ghissue:`3022`: Updating PyQt version checks for v4.10+
* :ghissue:`3021`: PyQt4 installation check fails as pyqtconfig is no longer built by default
* :ghissue:`2471`: Qt5 Backend
* :ghissue:`3068`: XDG_CONFIG_HOME causes server to crash
* :ghissue:`3010`: How to set multiple default fonts with matplotlib?
* :ghissue:`3001`: Install file got merge conflict 
* :ghissue:`3033`: Feature Request: Artists should have a name attribute?
* :ghissue:`3069`: vistrails ImportError: No module named pylab.plot
* :ghissue:`3015`: Date stem simplefix
* :ghissue:`2602`: stem function with datetime argument does not work in 1.3.1
* :ghissue:`3000`: PGF backend: Lines in multi-line text drawn at same position
* :ghissue:`3017`: Do not provide (wrong) mtext instances for pre-layouted text blocks (fixes #3000)
* :ghissue:`3009`: BUG: Showing a BboxImage can cause a segmentation fault
* :ghissue:`3061`: Add Axes.add_image() for consistency.
* :ghissue:`3063`: Change EPD links to Enthought Canopy
* :ghissue:`3050`: Animation example: rain drops
* :ghissue:`1891`: Animation module errors out when using Python3
* :ghissue:`1381`: Figure.add_subplot documentation doesn't explain args
* :ghissue:`2898`: Fix animation errors
* :ghissue:`3031`: avoid np.nan values in colors array returned by axes3d._shade_colors
* :ghissue:`3038`: BUG : expand x/y range in hexbin if singular
* :ghissue:`2863`: ensure non-singular extent in hexbin
* :ghissue:`3005`: Remove all references to ```ipython --pylab```
* :ghissue:`3048`: Animation example displaying earthquakes
* :ghissue:`3043`: CHANGELOG whats_new.rst / Re-generate simple auto legend
* :ghissue:`3040`: OSX 10.7 Install Error
* :ghissue:`3018`: Fix documentation of entropy function
* :ghissue:`2861`: Update backend_cairo.py
* :ghissue:`3028`: Import error QT4 backend with python3.2.3
* :ghissue:`3036`: Unicode fixes
* :ghissue:`2871`: Add a colorblind friendly heatmap.
* :ghissue:`2879`: BLD : adjust min six version to 1.3
* :ghissue:`3037`: DEP : removed levypdf from mlab
* :ghissue:`2974`: documentation mistake in errorbar
* :ghissue:`3025`: mpl issue: #2974 - documentation corrected
* :ghissue:`3030`: Fix minor typo in customisation docs
* :ghissue:`3026`: Bug in matplotlib.mlab.levypdf
* :ghissue:`3027`: Update mlab.py
* :ghissue:`2947`: Re-Generate legend, through apply_callback/Apply
* :ghissue:`3034`: A function to refresh the figure.
* :ghissue:`3014`: BUG : improved input clean up in Axes.{h|v}line
* :ghissue:`2197`: pyplot.errorbar: problem with some shapes of the positional arguments
* :ghissue:`2771`: Fix font family lookup calculation
* :ghissue:`3007`: #3005 - Removed 'ipython -pylab' references
* :ghissue:`3003`: PGF backend: Fix vertical positioning of multi-line text
* :ghissue:`2946`: remove .rect member (clashes with QWidget)
* :ghissue:`2839`: BUG : fixes non-float args to stem
* :ghissue:`2896`: add doc for qt repaint
* :ghissue:`2837`: EXP : turn of clipping in spine example
* :ghissue:`2772`: BUG : instantiate fall-back writer
* :ghissue:`2651`: in animation writer object not instanciated
* :ghissue:`2922`: ENH : add flag to box_plot and bxp to manage (or not) xticks
* :ghissue:`2921`: Boxplot resets x-axis limits and ticks
* :ghissue:`2950`: DOC : edits to optional dependencies
* :ghissue:`2490`: INSTALL should list ffmpeg/avconv/mencoder/imagemagick optional dependencies and versions
* :ghissue:`2916`: Docs build segfaults on Launchpad
* :ghissue:`2995`: Added 'interpolation_none_vs_nearest' example, without .DS_store files
* :ghissue:`3002`: BUG/DOC : fix bad merge of INSTALL
* :ghissue:`2965`: Feature Request: Data Cursor Mode
* :ghissue:`3006`: The FreeType extension defines add_flags, but is never called.  This
* :ghissue:`2899`: adding linewidth argument to pie
* :ghissue:`2993`: Avoid a null-pointer dereference in _tri.cpp
* :ghissue:`2994`: Minor fixes in _macosx.m
* :ghissue:`2559`: The response of mouse zoom & pan is slow with Qt4Agg backend.
* :ghissue:`2997`: Disable copying of C++ classes with nontrivial destructors
* :ghissue:`2998`: importing matplotlib breaks warn() function, when given an argument of type bytes
* :ghissue:`2992`: Remove a few dead assignments
* :ghissue:`2991`: Silence some compiler warnings related to ft2font
* :ghissue:`2969`: Tarball not installing on mac osx 10.9.2
* :ghissue:`2990`: Added 'interpolation_none_vs_nearest' example
* :ghissue:`2989`: Don't call Py_DECREF on null in _ttconv.cpp
* :ghissue:`2987`: OpenCV + figure.show() doesn't block GUI
* :ghissue:`2972`: aliasing with imshow(z, interpolation = 'none'), when saved as a pdf
* :ghissue:`2985`: let KeyErrors pass silently on callback removal
* :ghissue:`2979`: add 'buttons' parameter in LassoSelector and SpanSelector
* :ghissue:`2967`: Exception with sphinx 1.2.2 using the ipython directive
* :ghissue:`2984`: small error in install faq
* :ghissue:`2829`: (fix #2097) PGF: get fonts from fc-list, use builtin fonts for tests
* :ghissue:`2097`: PGF-related test failures on Mac OS-X
* :ghissue:`2976`: Gtk3Agg backend (Ubuntu 14.04)
* :ghissue:`2892`: Reset plot_directive context
* :ghissue:`2913`: Allow :context: directive to take 'reset' option. Fixes #2892.
* :ghissue:`2914`: Don't close figure if context and apply_rcparams are both set.
* :ghissue:`2890`: plot_apply_rcparams=True causes figure to not appear when updated
* :ghissue:`2983`: DOC/BUG : fixed sphinx markup
* :ghissue:`2982`: Docs build failure on Launchpad.
* :ghissue:`2981`: TST: __spec__ (an import-related variable for modules) was added in pyth...
* :ghissue:`2978`: BUG: EllipseCollection: fix transform error
* :ghissue:`2964`: line style rendering error
* :ghissue:`2968`: BUG: Fix the triangular marker rendering error.
* :ghissue:`2966`: axvline doc typo fix
* :ghissue:`2962`: py3k fix
* :ghissue:`2739`: DOC : improved `extent` of `imshow` doc
* :ghissue:`2960`: PEP8 : making pep8 happy again
* :ghissue:`2303`: Document figure.get_size_inches, improve set_size_inches and improve a ValueError message
* :ghissue:`2836`: DOC/ENH : get/set_size_inches
* :ghissue:`2953`: col2hex in figureoptions.py not versatile enough
* :ghissue:`2956`: Type of offset is int, not pointer.
* :ghissue:`2948`: DOC : added missing doc changes from #2844
* :ghissue:`1204`: Add power-law normalization
* :ghissue:`2452`: Fixed issues with errorbar limits
* :ghissue:`2955`: PEP8 : add missing line to un-break build
* :ghissue:`2925`: 'Dictionary size changed during iteration' in mathtext.py
* :ghissue:`2926`: BUG: Removes iteration over locals (no-no) in mathtext
* :ghissue:`2915`: Consistency of the radius argument for Path.points_in_path
* :ghissue:`2939`: Fixes a bug in drawing bitmap images in the macosx backend for handling device scaling
* :ghissue:`2949`: CLN : removed version check that required numpy > 1.2
* :ghissue:`2848`: DOC : removed line about un-needed dependencies in Windows
* :ghissue:`2330`: Documentation problem about installing matplotlib
* :ghissue:`2152`: We don't actually support Numpy v1.4
* :ghissue:`2943`: Typos in doc of vlines
* :ghissue:`2944`: Have pyplot.subplots return an np array no matter how many plots are created
* :ghissue:`2670`: Core dump with use.tex
* :ghissue:`2938`: Stem plots could handle dates, no?
* :ghissue:`2937`: Distortion of vertical axis labels that contain MathTeX (MacOSX backend)
* :ghissue:`2940`: Fix some documentation mistakes
* :ghissue:`2897`: add ccw pie test
* :ghissue:`2933`: #2897 Adding tests for pie ccw. Issue 2897
* :ghissue:`2936`: #2897 Resubmitting the pull request for Issue 2897
* :ghissue:`2932`: Py3K failure in ``transform.contains_branch``
* :ghissue:`2923`: Issue 2899
* :ghissue:`2930`: Cranky pep8
* :ghissue:`2847`: DOC : add link to `plt.subplots` from `Figure.add_subplot`
* :ghissue:`2919`: Import hangs when importing pyplot
* :ghissue:`2909`: BUG : add __hash__ to AffineBase
* :ghissue:`2924`: Pyplot figure window container
* :ghissue:`966`: axes_grid: indicate the axes for the suplot with append_axes
* :ghissue:`2906`: Fix Cairo text on Python3 with pycairo
* :ghissue:`2903`: Cairo Backend: Can't convert 'bytes' object to str implicitly on Python3
* :ghissue:`2775`: Compatibility with pandas 0.13
* :ghissue:`2920`: fix six check message
* :ghissue:`2546`: Candlestick shadow is drawn after candlestick body
* :ghissue:`2917`: NotImplemented Error with gtk3cairo
* :ghissue:`2912`: Fix paths in doc which are searched for matplotlibrc (XDG).
* :ghissue:`2735`: Fixes issue #966: When appending the new axes, there is a bug where it
* :ghissue:`2911`: text_axes missing cleanups
* :ghissue:`2905`: Cairo: fix TypeError in figure.text() on Python3
* :ghissue:`2870`: Wrong symbols from a TrueType font
* :ghissue:`2883`: Fixing building issues on OSX 10.9 when using a non-system python installation
* :ghissue:`2902`: Installer crash on Mac OS X 10.9.2 (crashed on child side of fork pre-exec)
* :ghissue:`2034`: Legend tuple handler improve
* :ghissue:`2834`: WebAgg: Fix IPython detection.  Fix encoding error on Python 3
* :ghissue:`2853`: counterclock parameter for pie
* :ghissue:`1664`: Support for skewed transforms
* :ghissue:`2901`: Trouble importing GTK when pyplot is imported
* :ghissue:`2844`: BUG : Qt repaint workaround on windows
* :ghissue:`2895`: typos: s/coodinate/coordinate & s/contols/controls
* :ghissue:`2894`: typo: s/contols/controls
* :ghissue:`2891`: wxversion
* :ghissue:`2601`: Legend does not work for ``quiver``
* :ghissue:`2875`: Fix for issue #2872. Skip NaN's in draw_path_collection.
* :ghissue:`2888`: Is there any way to keep the length between ticks in symlog plot the same?
* :ghissue:`2887`: fix a bug introduced in c998561d6cc1236
* :ghissue:`2882`: [arm] segfault with matplotlib.mlab.PCA  
* :ghissue:`2884`: Fixed the failing tests on master.
* :ghissue:`2878`: merging 1.3.x broke build on master
* :ghissue:`2159`: Add darken and lighten to colors
* :ghissue:`2537`: Clockwise pie diagram
* :ghissue:`2851`: Fix positional/kwarg handling of the Z argument
* :ghissue:`2808`: BUG: master has broken some 3d plots
* :ghissue:`2852`: AttributeError: 'module' object has no attribute 'next'
* :ghissue:`2876`: Added called process error to __all__
* :ghissue:`2860`: Fix subprocess.CalledProcessError on Google App Engine
* :ghissue:`2877`: `plt.xscale('log')` overrides grid
* :ghissue:`2865`: WebAgg: raise WebAggApplication.started flag before blocking
* :ghissue:`2872`: Matplotlib "eats" points when zeros present on logscaled scatter plot
* :ghissue:`2867`: GTK3 backend: implemented FigureCanvasBase.resize_event()
* :ghissue:`2868`: backend_qt4 qt4_editor figureoptions get_icon crashes application
* :ghissue:`2866`: 'rounding' of x coordinates in plt.plot with large 64-bit numbers
* :ghissue:`2864`: Frame around colorbar doesn't use closepath (in PDF renderer at least)
* :ghissue:`2862`: how to realize the function like surf(x,y,z,c) in matlab
* :ghissue:`2858`: BUG: colorbar autoscaling now ensures a finite range of values
* :ghissue:`2642`: FloatingPointError exception in figure.colorbar
* :ghissue:`2859`: BUG? subplot with sharex clears axes
* :ghissue:`2849`: WebAgg issue - Uncaught SyntaxError: Unexpected token & 
* :ghissue:`2856`: Add labels to points to aid data exploration
* :ghissue:`2840`: read Navigation toolbar parameters
* :ghissue:`2854`: DOC hist is not cumulative by default
* :ghissue:`2825`: WebAgg: extracted figure_div style into css and changed layout
* :ghissue:`2830`: Bug in multiple step horizontal histograms
* :ghissue:`1455`: Boxplot: allow whiskers to always cover entire range
* :ghissue:`2444`: Fixed bad vector transforms.
* :ghissue:`2795`: turn clipping off in spine example
* :ghissue:`2731`: 2d padding
* :ghissue:`2846`: Fix bug in horizontal step histograms (#2830)
* :ghissue:`2806`: BUGFIX: contour.py - add_label_near()
* :ghissue:`2818`: BUGFIX:  This change fixes #2475, and incorporates pull request #2806
* :ghissue:`2824`: WebAgg: drawing text is either skipped or duplicated
* :ghissue:`2776`: TST : add time out to ani.save
* :ghissue:`2819`: DOC: clarified docstring for cbook.boxplot_stats
* :ghissue:`2682`: sphinx documentation, links, [I hate] orange
* :ghissue:`2835`: quiver: handle autoscaling with quiverkey when animated
* :ghissue:`2616`: Quiver does not _init with animated=True and quiverkey attached
* :ghissue:`2777`: unicode strings `u''` have leaked into test_legend.py
* :ghissue:`2769`: squash smoke test on 3.2
* :ghissue:`2838`: TST : make 3.2 pass again
* :ghissue:`2630`: Qt4 save file dialog fails to appear on OSX
* :ghissue:`2347`: Colorbar autoscale handling an array of one value
* :ghissue:`1499`: twinx() on an inset axes wrongly acts on the main axes
* :ghissue:`2598`: colorbar() TypeError: only length-1 arrays can be converted to Python scalars
* :ghissue:`2815`: Bar plot width even for odd number of 'left' greater than 10
* :ghissue:`2832`: WebAgg Python3 ... strings again
* :ghissue:`2833`: path.simplify and path.simplify_threshold have no effect for SVG output
* :ghissue:`2826`: GTK3 backend: Replaced deprecated GObject calls with GLib
* :ghissue:`2805`: ENH: Updated inset locator axes to return a HostAxes by default
* :ghissue:`2652`: Axis tickmarks of 1e20 and higher fail
* :ghissue:`2281`: Documentation fails to build with Python 3
* :ghissue:`2807`: Python 3 METH_VARARGS with METH_KEYWORDS
* :ghissue:`2202`: Autoscale does not work for artists added with Axes.add_artist
* :ghissue:`2786`: eventplot raises an exception for empty sequences
* :ghissue:`2821`: DOC: point downloads at the matplotlib downloads
* :ghissue:`2817`: Provide 'lite' version of release tar file
* :ghissue:`2164`: [SPRINT] Single letter colors different than full name colors [sprint]
* :ghissue:`2809`: BUGFIX:  This change fixes #2475
* :ghissue:`2813`: GTK3Agg backend: Only convert the cairo context to a cairocffi context o...
* :ghissue:`2810`: Segfault when blitting multiple subplots with the gtk3agg backend
* :ghissue:`2814`: nanovg backend?
* :ghissue:`2811`: plot_surface displays darkened colormap
* :ghissue:`2801`: Named colors example
* :ghissue:`2804`: Fixed the image compare functionality.
* :ghissue:`2802`: Getting Exception with "loc" attribute in title
* :ghissue:`1995`: - wxPython Phoenix
* :ghissue:`2784`: Scipy2013 Sprint: Cleaning F/C example
* :ghissue:`2798`: Added remove methods for legends in figure and axes objects
* :ghissue:`2799`: Xdg message repr
* :ghissue:`2781`: Triplot returns the artist it adds.
* :ghissue:`2774`: changed the text of INSTALL to be correct about what external
* :ghissue:`2788`: MEP12: Clean-up line and marker demos
* :ghissue:`2787`: Empty event loop
* :ghissue:`2792`: Disable legend on matplotlib.axes instance
* :ghissue:`2779`: remove old animtion examples.
* :ghissue:`2027`: Old animation examples
* :ghissue:`2791`: Basemap background image has latitudes reversed
* :ghissue:`2789`: Hatching color in contourf function.
* :ghissue:`2715`: Upload packages to PyPI directly, for pip 1.5
* :ghissue:`2797`: Memory black hole in matplotlib animation.
* :ghissue:`2794`: fix typo in documentation
* :ghissue:`2793`: missing mask for scroll event
* :ghissue:`2668`: No "scroll_event" when using Gtk3 backends
* :ghissue:`2785`: Log plots (semilogx, semilogy and loglog) crash with type error
* :ghissue:`409`: Errorbar layering
* :ghissue:`2181`: Scipy2013 Sprint: Cleaning examples of api example
* :ghissue:`2780`: ENH : improve error invalid error message for subplot
* :ghissue:`2098`: figure.add_subplot(1311): ValueError: Illegal argument(s) to subplot: (1, 3, 1, 1)
* :ghissue:`2228`: Building docs: Could not import extension sphinxext.math_symbol_table (exception: No module named math_symbol_table)
* :ghissue:`2573`: Matplotlib install breaks pip?
* :ghissue:`2373`: python-dateutil encoding issues under python 3.3
* :ghissue:`2782`: BUG: quiverkey must set the vector figure attribute
* :ghissue:`2389`: table.py: fix issue when specifying both column header text and color
* :ghissue:`2729`: update list of dependencies
* :ghissue:`2748`: matplotlib 1.3.1 for Python 3.2.5 on Mac OS X produces corrupt .eps files
* :ghissue:`1962`: When legend is outside the axes, pick events get handled twice
* :ghissue:`2755`: Fixes legend.get_children() to actually return the real children of
* :ghissue:`1880`: KeyEvent's key attribute and modifier keys in WX backend
* :ghissue:`2599`: Create interpolation_methods.py
* :ghissue:`2586`: PGF backend does not clip image with specific bounding box
* :ghissue:`2621`: Simplify and fix dpi handling in tight_bbox
* :ghissue:`2752`: Make standardization of input optional in mlab.PCA
* :ghissue:`2773`: matplotlib 1.3.1 is broken on windows
* :ghissue:`2557`: Splitting navigation and toolbar
* :ghissue:`2726`: Don't snap pcolor
* :ghissue:`2760`: line color='none' regression in 1.3
* :ghissue:`2732`: AttributeError: 'Patch3DCollection' object has no attribute 'set_sizes'
* :ghissue:`2770`: No way to pass clear_temp to `Animation.save`
* :ghissue:`2442`: Rewrite of the entire legend documentation, including tidy ups of code and style to all things "legend".
* :ghissue:`2747`: Error with Savefig, Pyparsing
* :ghissue:`2746`: ENH : added warning on annotate
* :ghissue:`2675`: clip_on = False does not work for x-axis
* :ghissue:`1193`: Cairo backend ignores alpha in imshow. 
* :ghissue:`2768`: DOC/BUG: Fix references to demo files
* :ghissue:`2766`: Docs build failure
* :ghissue:`1027`: Possible bug in boxplot()
* :ghissue:`991`: Perfectly horizontal or vertical lines don't render to svg
* :ghissue:`841`: Error autoscaling histogram with histtype='step'
* :ghissue:`217`: New features for boxplot
* :ghissue:`2744`: handle NaN case nicely in _is_sorted
* :ghissue:`2761`: Fix line color handling
* :ghissue:`2763`: double_pendulum_animated.py in 1.2.1 fails due to clear_temp kwarg
* :ghissue:`2765`: There is no 1.2.2 out in the wild
* :ghissue:`2754`: changed timeout on travis so that smoketest stops timing out
* :ghissue:`2756`: Removes artificial limit in artist picker traversal. There are quite a
* :ghissue:`2543`: rcsetup.validate_bool_maybe_none(None) raises Exception
* :ghissue:`2555`: Make it possible to add mpl.rcParams to itself or deepcopy
* :ghissue:`2556`: Quiver leaks memory when called multiple times
* :ghissue:`2558`: fixes issue #2556
* :ghissue:`2767`: Transparency of overlaid contour fill without effect on underlying isocontours
* :ghissue:`2740`: MEP22 first draft (DO NOT MERGE)
* :ghissue:`2510`: Axes.margins() raises ValueError when only **kwargs is used
* :ghissue:`2762`: BUG : makes Axes.margins work with just kwargs
* :ghissue:`2590`: wrong version of mpl_toolkits imported when installing mpl with python setup.py install --user
* :ghissue:`2730`: ENH : added test on number of large differences between images
* :ghissue:`2643`: ENH/REF: Overhauled boxplots
* :ghissue:`2669`: PGF backend can't find 64-bit ghostscript on win64
* :ghissue:`2540`: Location of subplot.set_aspect(...) matters for imshow
* :ghissue:`2605`: cxx error when installing matplotlib 1.3 on CentOS 5.9
* :ghissue:`2622`: Matplotlib fails to build with Freetype 2.5.1 on OS X
* :ghissue:`2687`: `plt.xkcd()` gives an error when a plt.text() is added with two line breaks "\n\n"
* :ghissue:`608`: mpl_toolkits.axisaritst should implement separate artists for x- and y- gridlines
* :ghissue:`2655`: The "2to3" seems doesn't work while buliding matplotlib1.3.1 with python3.x
* :ghissue:`1733`: im.set_clip_path(rectangle) doesn't work
* :ghissue:`2734`: Fixed issue #1733 - AxesImage draw function now takes into account the
* :ghissue:`2757`: Added missing warnings import
* :ghissue:`2135`: Test toolkits rebase
* :ghissue:`2750`: Jitter plot
* :ghissue:`1736`: Implement a Colormap.__reversed__
* :ghissue:`2753`: BUG : fixes py3k import
* :ghissue:`2256`: Can't import plot_directive in Python 3
* :ghissue:`1227`: Does the gtk3agg backend work on python3?
* :ghissue:`1030`: patch facecolor does not respect alpha value
* :ghissue:`1703`: matploblib ignoring the switching of rendering backends
* :ghissue:`2710`: Fixed empty text bbox drawing.
* :ghissue:`2751`: BUG : fix failing test on 3.2
* :ghissue:`1429`: [sphinxext] needs ability to build html without the link to source
* :ghissue:`1203`: multi-subplot animation problem
* :ghissue:`2633`: svg from filenames containing '--' can be illformed
* :ghissue:`1148`: Matplotlib doesn't save correctly the figuren when using patches.Circle on different plots
* :ghissue:`2264`: Qt4Agg does not send backspace key_press_events
* :ghissue:`1947`: Generate thumbnail of figure contents for use as figure window icon
* :ghissue:`2529`: unable to build docs locally
* :ghissue:`2741`: seg-fault building docs
* :ghissue:`1529`: Unsatisfactory API example
* :ghissue:`2749`: Qt4 keys
* :ghissue:`2137`: PIL -> Pillow
* :ghissue:`2302`: mpl_connect event.key has 'alt' prepended in matplotlib 1.2 on windows
* :ghissue:`2212`: spyder and matplotlib
* :ghissue:`2273`: Qt4 keys
* :ghissue:`2733`: doc on rebase a pull request
* :ghissue:`2276`: implemented support for asymmetric margins.
* :ghissue:`2263`: Correct setup of margins for logarithmic plots
* :ghissue:`1992`: QT backend: Post-plotting layout values set via GUI get lost after zoom-in/zoom-out cycle
* :ghissue:`1311`: textcords='axes fraction'  does not work for some axes ranges
* :ghissue:`1712`: Pylab function show()  accepts any arguments
* :ghissue:`1567`: Create kwarg to normalize histogram such that sum of bin values equals 1
* :ghissue:`2169`: [SPRINT] Much better alpha control in mplot3d. Closes #1541
* :ghissue:`829`: tight_layout: take suptitle into account?
* :ghissue:`2249`: Autocompletion on rcParams: long-overdue restructuring of rcParams
* :ghissue:`2118`: rc_file does not restore settings from my matplotibrc
* :ghissue:`2737`: Duplicate month name in AutoDateLocator on DST timezones
* :ghissue:`1408`: Feature request: streaklines and improvements to streamplot
* :ghissue:`1060`: AutoDateLocator.__init__: add version since which keywords are available
* :ghissue:`2237`: Interactive plot styling 
* :ghissue:`1413`: Reminder: PySide decref patch
* :ghissue:`990`: imshow extent keyword (documentation?)
* :ghissue:`379`: Axes objects to hold dictionary of axis objects
* :ghissue:`2477`: Add image value to x=, y= cursor text.
* :ghissue:`2483`: animation with 'ffmpeg' backend incompative with 'bounding_box=tight'
* :ghissue:`2218`: color should set both facecolor and edgecolor in pyplot.bar
* :ghissue:`2566`:  hsv_to_rgb isn't the inverse of rgb_to_hsv
* :ghissue:`1561`: mlab.psd returns incorrect frequency axis for two-sided spectra with nfft odd.
* :ghissue:`2365`: Missing final edge in a 'step' histogram for matplotlib 1.3.0
* :ghissue:`2346`: 2.7.5-r2: Fatal Python error: Segmentation fault at matplotlib/transforms.py", line 2370 in get_matrix
* :ghissue:`2305`: Request: Set figure size in pixels, not inches
* :ghissue:`2214`: new figure invoked from a python shell in Emacs for win32 freezes console even after it's closed
* :ghissue:`2235`: Broken doc build
* :ghissue:`1901`: Qt4Agg + PySide fails to open a plot on linux64 (CentOS-5,6)
* :ghissue:`1942`: Matplotlib widgets: How to disconnect spanselector once selection is completed?
* :ghissue:`1952`: import pylab; pylab.plot([1,3,2]): Failed to load platform plugin "xcb"
* :ghissue:`1863`: SpanSelector broken in master
* :ghissue:`1586`: frameon=False shifts plot axes to to the right and increases figure width
* :ghissue:`2121`: geo_demo fails on OpenBSD
* :ghissue:`2091`: PEP8 conformance test fails without listing location of failures
* :ghissue:`1738`: Issue building on OSX 10.8.2
* :ghissue:`1080`: patch for building with mingw32
* :ghissue:`867`: Plots with many subplots can be slow
* :ghissue:`912`: FreeSans horizontal misalignment in PDF, SVG, PS backends
* :ghissue:`1594`: python3.3m/longintrepr.h:49: error: ‘PY_UINT32_T’ does not name a type
* :ghissue:`339`: Use scrollbars when figure size is larger than screen
* :ghissue:`1520`: "`TextPath` imported but not used", says `pyflakes`
* :ghissue:`1614`: Segfault ufunc_object.c:1750
* :ghissue:`1627`: TkAgg backend: draw_if_interactive() broken?
* :ghissue:`1309`: matplotlib.tests.test_mathtext.mathfont_cm_23_test.test makes python debug to crash
* :ghissue:`338`: Interactive Compass object
* :ghissue:`1805`: Each pyplot function deserves its own page
* :ghissue:`1371`: vertical alignment of yticklabels fails on `0`
* :ghissue:`1363`: error in matplotlib.pyplot.plot_date doku?
* :ghissue:`1308`: plot_date should not use markers by default
* :ghissue:`1245`: Cairo Backend: print_surface
* :ghissue:`224`: Faster implementation of draw_rubberband in GTK+ backend
* :ghissue:`429`: undefined behavior of figure.add_subplot() once subplot is modified.
* :ghissue:`2673`: 'key_press_event' registering keypresses as alt-key combo (win8, python3.3, matplotlib 1.3.1)
* :ghissue:`2466`: Implementation of separate horizontal/vertical axes padding to the axis_grid toolkit
* :ghissue:`2705`: Build fails on OS X with NumPy 1.9
* :ghissue:`2707`: Callable date formatter
* :ghissue:`1299`: Update Axes3D.tricontour for custom triangulations
* :ghissue:`2007`: mixed backend rely on __getattr__ method
* :ghissue:`2176`: Adjustments to contour.py so that levels are set accordingly to input vmin and vmax, if provided, so color bar works correctly.
* :ghissue:`2474`: MEP12: Example clean-up for reference
* :ghissue:`2727`: Typo in explanation of annotation_demo
* :ghissue:`2728`: fixed comment white space pep8
* :ghissue:`666`: griddata constant spacing check needs tweaking
* :ghissue:`2313`: mlab.griddata() more robust check for constant spacing
* :ghissue:`2720`: Look for user-specified styles in ~/.config/matplotlib/stylelib
* :ghissue:`2712`: Anchored sizebar fontprop
* :ghissue:`2713`: Compare pep
* :ghissue:`2717`: Unexpected behaviour in errorbar
* :ghissue:`2207`: color of candlestick lines
* :ghissue:`2551`: Fix behavior of hist function when passed empty dataset
* :ghissue:`2595`: EHN: add a span_stays option to widget.SpanSelector
* :ghissue:`2647`: use GridSpec in plt.subplots
* :ghissue:`2724`: Documentation for WeekdayLocator.byweekday parameter incorrect?
* :ghissue:`2725`: DOC : fixes small typos in matplotlib.dates docs
* :ghissue:`2714`: Deprecated matplotlib.testing.image_util.
* :ghissue:`2691`: Change LogFormatterExponent to consistently format negative exponents
* :ghissue:`2719`: Package initialization made possible when executed in environments with...
* :ghissue:`2723`: Backend selection without $DISPLAY available
* :ghissue:`2718`: Added missing cleanup decorator import.
* :ghissue:`2695`: Matplotlib useable on clusters with read-only resp. non-existing home directories on compute nodes.
* :ghissue:`1907`: Timers independent of canvases
* :ghissue:`1780`: New colormap normalizations: sqrt, arcsinh
* :ghissue:`1519`: new methods set_xlabel and set_ylabel in "class Figure"
* :ghissue:`1254`: backend_cairo.py -- added print_surface method
* :ghissue:`1200`: Hatch linewidth for pdf and ps backends (#235).
* :ghissue:`1143`: [Sprint] Matlab fplot
* :ghissue:`1134`: Enable mlab.rec2txt() to write small floats instead of just zero
* :ghissue:`827`: make hist histype='step' return list of container instead list of list
* :ghissue:`701`: modify pcolor so masked elements are plotted with color specifed in cmap.set_bad
* :ghissue:`801`: tight_labels
* :ghissue:`2248`: axes_grid1: ImageGrid respect the aspect ratio of axes. 
* :ghissue:`2585`: Improvements to anchored_artists.AnchoredSizeBar
* :ghissue:`2481`: datestr2num of year and month fails on 29th, 30th, and 31st of month
* :ghissue:`2423`: Off-axes markers unnecessarily saved to PDF
* :ghissue:`2500`: WIP: Fix streamplot set
* :ghissue:`2239`: Update of mlab.pca - updated docstring, added saving the eigenvalues.
* :ghissue:`2592`: api docs for matplotlib.artist.get and matplotlib.artist.getp are exactly the same
* :ghissue:`1747`: NotImplementedError: cannot remove artist
* :ghissue:`2525`: cfl() doesn't clear gcf()._suptitle
* :ghissue:`2711`: Fixes issue #2525
* :ghissue:`2704`: Bugfix for issue #1747. Allows removal of figure text artists.
* :ghissue:`2696`: Fix Tk keyboard modifier masks on Windows
* :ghissue:`2709`: matplotlib colors darker than equivalent matlab colors
* :ghissue:`2690`: Build failure on MacOS X 10.5.8 (PowerPC G5) with Python 3.3.3
* :ghissue:`2507`: AutoDateFormatter: More customizable formatting
* :ghissue:`2628`: improved get_ticklabels kwarg
* :ghissue:`1715`: axes.get_xticklabels() doesn't return all tick labels.
* :ghissue:`2634`: address FuncAnimantion trying to take lengths of generators
* :ghissue:`1769`: FunctionAnimator tries to take length of iterator
* :ghissue:`2468`: Add "sage" colors to colors.py
* :ghissue:`2520`: Adds option to plot average in boxplot, besides the median
* :ghissue:`2432`: Rotate markers in Scatter plot
* :ghissue:`2521`: Fix backend_svg.RendererSVG.draw_text to render urls
* :ghissue:`2703`: Updating regex used to split sphinx version string.
* :ghissue:`2701`: Fix FancyBboxPatch Typo
* :ghissue:`2653`: Inconsistent streamplot grid size
* :ghissue:`2700`: Consistent grid sizes in streamplot.
* :ghissue:`2689`: Disable offset box clipping by default.
* :ghissue:`2530`: AnchoredOffsetBox not taken into account by bbox_inches='tight'
* :ghissue:`2693`: Use mpl.checkdep_ghostscript function to find ghostscript
* :ghissue:`2692`: _get_xdg_config_dir(), _get_xdg_cache_dir() - Restored for conformity to the standard.
* :ghissue:`1809`: Delaunay bug: bad triangulations (intersecting triangles)
* :ghissue:`2679`: Make `test_save_animation_smoketest` actually run
* :ghissue:`2660`: Error with _compute_convex_hull on certain triangulations. 
* :ghissue:`2504`: Using qhull for Delaunay triangulation
* :ghissue:`2683`: Close a figure with a type long or uuid figure number
* :ghissue:`2583`: Pylab figure becomes unresponsive after an error
* :ghissue:`2677`: Make sure self._idle is set to `True` in all cases
* :ghissue:`2597`: BUG: Add subplot spec  eq  
* :ghissue:`2650`: Lightsource shade method parameters for color range definition
* :ghissue:`2665`: MacOSX backend supports 2x DPI images and MathTeX.
* :ghissue:`1958`: Macosx: Retina displays are not supported
* :ghissue:`2112`: New subplottool and various fixes
* :ghissue:`2680`: Deprecate toolbarqt4agg
* :ghissue:`2685`: Remove a redundant comparison that raises an exception in Python 3
* :ghissue:`2657`: different fix for comparing sys.argv and unicode literals
* :ghissue:`2646`: Fix Gtk3 crash when running inside of IPython
* :ghissue:`2661`: NF - see axes.get_label() when clicking on Edit curves lines and axes pa...
* :ghissue:`2681`: Plotting a matrix fails with maximum recursion depth exceeded.
* :ghissue:`2676`: Fix typo in _axes.vlines doc-string
* :ghissue:`2569`: Explicitly cast the input array to float before doing anything to it
* :ghissue:`2607`: Allow global customization of ticker params
* :ghissue:`2672`: Exporting 3d plots as u3d files
* :ghissue:`2671`: Deprecate IPython-related Sphinx extensions
* :ghissue:`2674`: properties instead of set_ and get_
* :ghissue:`2666`: Deprecate IPython-related Sphinx extensions
* :ghissue:`2656`: Use IPython's copy of ipython_console_highlighting Sphinx ext, if available
* :ghissue:`2515`: overloaded `_make_twin_axes` on `LocateableAxesBase` 
* :ghissue:`2659`: DOC: Remove redundant colormaps from examples
* :ghissue:`2658`: "float() argument must be a string or a number" when saving a png
* :ghissue:`2636`: "\usepackage[russian]{babel}" does not work in matplotlib 1.3.1
* :ghissue:`2648`: Update backend_webagg.py
* :ghissue:`2641`: plot_date: Set the default fmt to 'o'
* :ghissue:`2593`: I'd like to see axes.get_label() when clicking on 'Edit curves lines and axes parameters' after plt.show()
* :ghissue:`2645`: Add option to show/hide the source link in plot_directive
* :ghissue:`2644`: Small typo in the license.
* :ghissue:`532`: Figure.tight_layout() error or doesn't work on Win with wxPython
* :ghissue:`1732`: Explicitely passing an axes to share axis with
* :ghissue:`2461`: New style format str
* :ghissue:`2503`: Fix interactive mode detection
* :ghissue:`2640`: Axes.plot: remove set_default_color_cycle from the docstring
* :ghissue:`2639`: BUGFIX: ensure that number of classes is always of type INT in Colormap
* :ghissue:`2638`: TypeError: Cannot cast scalar from dtype('float64') to dtype('int64') according to the rule 'same_kind'
* :ghissue:`2629`: backend_qt4agg: remove redundant classes.  Closes #1151.
* :ghissue:`1151`: FigureManagerQT used in new_figure_manager of Qt4Agg backend
* :ghissue:`2631`: BUG Raise exception for invalid input
* :ghissue:`2594`: New layout for qt4 subplottool + QMainWindow -> QDialog
* :ghissue:`2623`: setupext: put pkg-config -I, -L, -l locations at the head of the list
* :ghissue:`1451`: 3D animation example no longer works.
* :ghissue:`1172`: Axes.tick_params() fails with labelsize=<string> and direction='out'
* :ghissue:`2610`: improve docstring and add test fot to_rgb(<float>)
* :ghissue:`2609`: to_rgb(float) or to_rgb(str(flot))
* :ghissue:`2618`: Fix issue 1172
* :ghissue:`2619`: slight tweak to mpl_example
* :ghissue:`2626`: minor pep8 to fix failing master builds.
* :ghissue:`2482`: animation fails to create a movie with 'ffmpeg_file' backend
* :ghissue:`2443`: Fix PEP8 test failures on master
* :ghissue:`2604`: adding global variable to keep track if gtkmain has been called
* :ghissue:`2617`:  factor the pyplot dependence out of the figure_manager classes
* :ghissue:`1545`: gtk backend should switch to gtk.Builder
* :ghissue:`2606`: embedding_webagg example: Download button does not work
* :ghissue:`1646`: Interactive mode broken in Qt4Agg backend?
* :ghissue:`1745`: hist again... normed=True, stacked=True doesn't make sense
* :ghissue:`2588`: Refactor mechanism for saving files.
* :ghissue:`1196`: errorbar bars don't respect zorder
* :ghissue:`2412`: FAIL: matplotlib.tests.test_axes.test_single_point.test
* :ghissue:`2411`: FAIL: matplotlib.tests.test_axes.test_symlog2.test
* :ghissue:`2410`: matplotlib.tests.test_image.test_rasterize_dpi.test failure
* :ghissue:`2329`: set_position on Annotation is not working
* :ghissue:`1486`: ENH: Boxplot median and confidence intervals computed with user-spec'd function
* :ghissue:`1181`: NF - Text numeric values for ha and va
* :ghissue:`2614`: Initialization fails if get_home() returns None
* :ghissue:`2615`: Fixes issue #2482 and adds note in matplotlibrc.template
* :ghissue:`2493`: Solve issue #2482
* :ghissue:`2613`: BLD Fix build failure on Python 3.4b1 for Windows
* :ghissue:`2459`: pep8 for backend_pdf.py
* :ghissue:`2612`: Traitlets
* :ghissue:`2409`: Fix bugs related to bottom kwarg in step histograms
* :ghissue:`2549`: Add methods to control theta position of r-ticklabels on polar plots
* :ghissue:`2567`: more informative exceptions for empty/not-existing images in compare_images()
* :ghissue:`2473`: black background on rasterized quadmesh in ps output
* :ghissue:`2603`: Correcting bad string comparsion in lin-log plot aspect verification
* :ghissue:`697`: Partial coloring of text
* :ghissue:`2561`: multi-colored text example
* :ghissue:`2236`: Add easy style sheet selection
* :ghissue:`2600`: register Axes3D along with other projections
* :ghissue:`2582`: fix initialization of AnnotationBbox 
* :ghissue:`2574`: Add axes.titleweight as an rc param
* :ghissue:`2579`: MultiCursor: make events connected during __init__ accessible (for later removal)
* :ghissue:`2591`: Fix infinite recursion in units with ndarray subclasses.
* :ghissue:`1625`: saving pgf to a stream is not supported
* :ghissue:`2587`: Make backend_pgf more flexible when saving to file-handles or streams (fix #1625).
* :ghissue:`2554`: User Guide Structure
* :ghissue:`2565`: mlab.psd behavior change
* :ghissue:`2571`: This fixes thee probllem brought up in the mailing list with the recent spectrum improvements
* :ghissue:`2589`: mathtext rendered does't work with bundled pyparsing.py module
* :ghissue:`2544`: Fix 2542
* :ghissue:`2542`: Visual glitch in Axes borders
* :ghissue:`2584`: Fix typo in legend documentation
* :ghissue:`2578`: pie_chart_with_horizontal_bar_chart added
* :ghissue:`2400`: Feature request: rc parameter for 'useOffset=False'
* :ghissue:`461`: ScalarFormatter creates useless offsets by default
* :ghissue:`2576`: ENH: Change default value of useOffset to false in ScalarFormatter.
* :ghissue:`2401`: adds rcParam `axes.formatter.useoffset`
* :ghissue:`2495`: fixed an enconding bug when checking for gs version
* :ghissue:`2581`: AffineBase.__eq__ should not raise an exception when the other does not ...
* :ghissue:`2572`: PPA for Precise
* :ghissue:`2564`: Axes3D scatter changes the color in version 1.2.1 during rotation
* :ghissue:`2462`: Path effects update
* :ghissue:`2570`: matplotlib 1.3.0 doc build for mac osx 10.9 
* :ghissue:`2364`: No official build of OSX version on the download page.
* :ghissue:`2563`: Cannot hide axes ticks with log-scales
* :ghissue:`2562`: Just some small tweaks to the recipes
* :ghissue:`2550`: Using a single-shot timer with the Wx backend raises an AttributeError
* :ghissue:`2198`: Fix compilation on Solaris
* :ghissue:`2552`: after use('Agg'), the animate does not work well
* :ghissue:`2553`: removing items from the call to six.iteritems
* :ghissue:`2547`: fix removed api change regarding spectral functions
* :ghissue:`2514`: Mpl toolkit pep8
* :ghissue:`883`: bbox_inches="tight" causes huge figures and text far outside figure frame
* :ghissue:`2548`: Zoom/pan shifts displayed surface.
* :ghissue:`2538`: streamplot hangs in application embedding Python interpreter
* :ghissue:`2522`: Add additional spectrum-related plots and improve underlying structure
* :ghissue:`2535`: Move external libraries to 'extern' directory - correction
* :ghissue:`2534`: cast argv to unicode before testing
* :ghissue:`2531`: Move external libraries to 'extern' directory
* :ghissue:`2526`: Minor doc fixes
* :ghissue:`2523`: Unicode issue in EPS output when using custom font
* :ghissue:`2513`: Patch disconnected when moved to another axes.
* :ghissue:`2479`: Rastized background color
* :ghissue:`2512`: Fix saving to in-memory file-like objects in Postscript backend
* :ghissue:`2472`: Plots using twinx draw on top of figure frame
* :ghissue:`842`: Patch.update_from does not preserve the facecolor when alpha is set. 
* :ghissue:`792`: Make tests pass under *all* freetype versions
* :ghissue:`2498`: savefig() with StringIO.StringIO() object failing for PS backend on Python 2.7.5
* :ghissue:`2252`: Transparent SVGs not rendered correctly in PDF with `ipython nbconvert`
* :ghissue:`2485`: ENH better error message when wrong cmap name.
* :ghissue:`2505`: [Wishlist] fontproperties of table
* :ghissue:`2489`: tiny correction of matplotlibrc.template
* :ghissue:`2506`: minor docstring fix in dates.py
* :ghissue:`2491`: Re-enabled PEP8 test, closing #2443.
* :ghissue:`2501`: ttfFontProperty fails with invalid/misconfigured fonts
* :ghissue:`2502`: Updated the docs of pyplot.gca.
* :ghissue:`2428`: BUG: Fixed object type missmatch in SymLogNorm
* :ghissue:`2497`: Handle floats with commas in AFM files
* :ghissue:`2496`: Adding a missing 'b' back into two 'bbox_' kwargs
* :ghissue:`2494`: Update scatter_demo.py
* :ghissue:`2484`: Fixes issue #2482 and recasts xrange as iter
* :ghissue:`2486`: make pep8 test routine reusable for other projects
* :ghissue:`2480`: Use Pillow always on Travis
* :ghissue:`2406`: BUG: Fixed github stats retrieval
* :ghissue:`2441`: Catch stderr as well as stdout
* :ghissue:`2415`: Bug: alpha parameter was ignored when fill color is #000000
* :ghissue:`2300`: would crash if get_home() returns None
* :ghissue:`2420`: Refactor WebAgg so it can communicate over another web server
* :ghissue:`2447`: BUG: Fix boxplots with manual confidence intervals passed as a numpy array
* :ghissue:`2453`: PdfPages: add option to delete empty file when closed
* :ghissue:`2458`: pep8 clean up 
* :ghissue:`2463`: _tri breaks build on Cygwin
* :ghissue:`2156`: [Sprint] scatter plots are (reportedly) too slow
* :ghissue:`1814`: ipython and matplotlib
* :ghissue:`2464`: Rename C++ variables to avoid use of reserved identifiers
* :ghissue:`2470`: ENH: use checkdep_ghostscript to determine ghostscript executable
* :ghissue:`2469`: BUG: gswin64c.exe not detected on Windows
* :ghissue:`2476`: Updated the position of a few of the text examples because they were overlapping and hard to read.
* :ghissue:`2379`: Make matplotlib.test() print meaninful messages when baseline images are not installed
* :ghissue:`2293`: 1.3.0: type of `hist` return value changed
* :ghissue:`2418`: AssertionError with quiver, quiverkey, and an additional patch.
* :ghissue:`2425`: DOC: `axis_off` wrongfuly appears as a parameter to Figure.add_subplot
* :ghissue:`2196`: 1.3.0rc4: FAIL: matplotlib.tests.test_image.test_rasterize_dpi.test
* :ghissue:`2445`: Declare Numpy as a setup dependency
* :ghissue:`2336`: Added check in autoscale_None for completely masked pcolor plots.
* :ghissue:`2377`: ConnectionPatch "axis fraction" failure when axesB contains a plot
* :ghissue:`2460`: minor pep8 fix on every file
* :ghissue:`2457`: Privatize Text.cached
* :ghissue:`2433`: Handle Unicode font filenames correctly/Fix crashing MacOSX backend
* :ghissue:`2455`: Gitignore update
* :ghissue:`2454`: AxesImage.set_cmap() and AxesImage.set_clim() have no effects.
* :ghissue:`2446`: Don't set use_2to3 unless we have to.
* :ghissue:`2449`: Qt4 clear before draw
* :ghissue:`2424`: remove some redunancy in _BaseAxes
* :ghissue:`2435`: Explicitly catch TypeError when doing pyparsing monkeypatch check
* :ghissue:`2440`: Pdfpages pagecount convenience getter method
* :ghissue:`2437`: Fix randomly failing tests
* :ghissue:`2099`: Updated coding standards test to raise an exception containing the PEP8 failiures.
* :ghissue:`2439`: Use six.string_types instead of basestring.
* :ghissue:`2438`: Use six.string_types instead of basestring.
* :ghissue:`2289`: speedup figure rendering removal of .startswith() calls and use generato...
* :ghissue:`2431`: BUG: in font_manager, handle unicode output from fontconfig
* :ghissue:`2436`: Catch explicit exceptions when setting locale
* :ghissue:`2430`: Document API change in hist
* :ghissue:`2311`: Use mimetypes module rather than try to implement our own
* :ghissue:`2416`: Multipage pdf with statement
* :ghissue:`2427`: DOC: Add axes_api to documentation after the refactoring
* :ghissue:`2271`: docs: add webagg-backend
* :ghissue:`2417`: Adding possibility to remove invisible lines and patches from relim
* :ghissue:`2429`: Document API change in hist
* :ghissue:`947`: Explain @cleanup decorator in testing documentation
* :ghissue:`2096`: Drawing a histplot crashes deeply inside matplotlib
* :ghissue:`2242`: DOC:Use monospace for --
* :ghissue:`2426`: Remove dead rms computation
* :ghissue:`2421`: docstring fix
* :ghissue:`2419`: extra ticklocs and ticklabels when plotting with bar(log=True) in matplotlib >= 1.3
* :ghissue:`2378`: issues with `unicode_literals` and `pysides.QtCore.Slot`
* :ghissue:`2414`: Adding the possibility to exclude invisible lines and patches in relim
* :ghissue:`2382`: New stlye qt calls
* :ghissue:`2351`: Annotation refactor
* :ghissue:`2297`: Fix bugs related to bottom kwarg in step histograms
* :ghissue:`2117`: fixes #2097, pgf: get scalable system-fonts from fontconfig, rely on builtin fonts for tests
* :ghissue:`2408`: backend_pgf: fix str/unicode comparison errors (v1.3.x)
* :ghissue:`2407`: backend_pgf: fix str/unicode comparison errors
* :ghissue:`2403`: PGF backend tests failing
* :ghissue:`2404`: Fix backend_ps.py
* :ghissue:`2405`: Operator '<<' is deprecated, use '<<=' instead
* :ghissue:`2399`: TypeError occurs when self.button=None in MouseEvents
* :ghissue:`2402`: support tight_bbox for pgf output, fixes #2342 (v1.3.x)
* :ghissue:`2391`:  support tight_bbox for pgf output, fixes #2342
* :ghissue:`2342`: savefig PGF - RuntimeError: Cannot get window extent w/o renderer
* :ghissue:`2398`: printing MouseEvents throws TypeError when button==None
* :ghissue:`2397`: request : could the default windows font of matplotlib support an utf-8 "µ" ?
* :ghissue:`2396`: Try UNIXy and Windowsy ways of setting locale
* :ghissue:`2392`: PDF link for documentation of version 1.3.0 gets documentation for version 1.2.1
* :ghissue:`2331`: Make optional backends respect setup.cfg
* :ghissue:`2393`: use six.move for cStringIO
* :ghissue:`2372`: Fix step histogram endline
* :ghissue:`2395`: Drawing arrows correctly in log scale plots is too hard
* :ghissue:`2385`: fix forgotten cStringIO replacement when replacing 2to3 with six
* :ghissue:`2384`: Make background transparent by default when saving figure
* :ghissue:`2388`: Set default for transparency savefig
* :ghissue:`2390`: Transparent rcparams
* :ghissue:`2383`: BUG: Fix IndexError: too many indices with numpy 1.8
* :ghissue:`2376`: feature test pyparsing 2 bug instead of version check
* :ghissue:`2386`: locale breaks test suite
* :ghissue:`2229`: Matplotlib does not display hatching when rendering to pdf in fill_between
* :ghissue:`2371`: Corrections to cbook.warn_deprecated calls().
* :ghissue:`2381`: don't install python-dateutil==2.1 on python 3.3
* :ghissue:`2380`: check if pyparsing <<= is broken instead of checking the version
* :ghissue:`2374`: Doc fix typos
* :ghissue:`788`: font_styles test failing for some people
* :ghissue:`1115`: Pass text alignment information to the PDF, PGF and PS backends
* :ghissue:`1121`: Cairo text is misaligned vertically
* :ghissue:`1157`: Use automatic dependency installation
* :ghissue:`1342`: Make test data install optional
* :ghissue:`1658`: WebAgg backend blocks
* :ghissue:`2021`: Running tests in parallel occasionally hangs in unpredictable ways
* :ghissue:`2062`: Deprecate our IPython-related Sphinx directives
* :ghissue:`2286`: Don't enable "interactive mode" if not at the console
* :ghissue:`2368`: Set locale for tests
* :ghissue:`2226`: Stop relying on 2to3 and use `six.py` for compatibility instead
* :ghissue:`2320`: fail to import matplotlib.pyplot
* :ghissue:`2310`: Fix wrong binding of JS this
* :ghissue:`2335`: make sure we only perform absolute imports on loading a backend
* :ghissue:`2309`: use('module://') directive doesn't work as expected
* :ghissue:`2192`: Follow the PSF code of conduct
* :ghissue:`2367`: Fix a number of long-failing tests
* :ghissue:`2363`: [bug correction] trirefine is now independant of triangulation numbering
* :ghissue:`2356`: Bad xlim/ylim when using shared axes subplots and an empty subplot
* :ghissue:`2357`: Better axis limits when using shared axes and empty subplots
* :ghissue:`2362`: Non-ascii font name makes `matplotlib.pyplot` fail at import
* :ghissue:`2358`: Broken IPython notebook integration
* :ghissue:`2296`: rc defaults incorrectly interpreted by colorbar
* :ghissue:`2352`: changed colorbar outline from a Line2D object to a Polygon object
* :ghissue:`2354`: Possible memory leaks reported by valgrind
* :ghissue:`2054`: Ipython/Webagg integration
* :ghissue:`2191`: Write a dependency policy
* :ghissue:`2301`: Upload test result images to Amazon S3
* :ghissue:`2348`: Ignore any non-ascii characters when reading font information.
* :ghissue:`2319`: fix draw_idle reference in  NavigationToolbar2
* :ghissue:`2349`: Plot errorbars as boxes instead of bars
* :ghissue:`2345`: texmanager font selection crashes
* :ghissue:`2307`: font_manager.py UnicodeDecodeError when starting ipython --pylab
* :ghissue:`2306`: Mollweide latitude grid
* :ghissue:`2299`: Mollweide projection no longer shows horizontal gridlines
* :ghissue:`1648`: RuntimeError: No SFNT name table
* :ghissue:`2325`: BF: guard against broken PyQt import
* :ghissue:`2327`: Bar demo2 improve
* :ghissue:`2332`: Except AttributeError when checking for gtk3 backends
* :ghissue:`2134`: MatPlotLib Figure Freezing on Windows 
* :ghissue:`2340`: Fix #2339: render math text when using path effects
* :ghissue:`2338`: issues with pyparsing 1.5.7 and python 2.7
* :ghissue:`2334`: Remove disabled code.
* :ghissue:`2344`: Fixed the issue of pyplot tutorial missing the show() command
* :ghissue:`2339`: Math text with path effects is rendered as plain text
* :ghissue:`2337`: pylot tutorial's codes are missing statements
* :ghissue:`2308`: Make pyplot.bar color kwarg less ambiguous
* :ghissue:`2333`: Fix wrong syntax for assert
* :ghissue:`2321`: PDF backend failure
* :ghissue:`2318`: clean up of Qt namespace breaks PySides
* :ghissue:`2326`: BUG FIX for Pull Request #2275: Fix incorrect function calls
* :ghissue:`2328`: Fix PySide compatibility
* :ghissue:`2323`: Axes cannot be animated using animation.py with blit
* :ghissue:`2322`: Axes cannot be animated using animation.py with blit
* :ghissue:`2312`: Replace the obsolete wx.PySimpleApp in the demo file embedding_in_wx5
* :ghissue:`2316`: Replace the obsolete wx.PySimpleApp
* :ghissue:`2317`: fix the docstring for scale_docs
* :ghissue:`2244`: Upgrade requirement to pyparsing 2.0.1, and fix pyparsing deprecation warnings
* :ghissue:`2109`: rcparam['axes.grid']=True   != axes.grid(True) ?
* :ghissue:`2110`: Fix rc grid parameter inconsistency
* :ghissue:`197`: FigureCanvasMac.flush_events() raises NotImplementedError
* :ghissue:`2278`: Can't find 64-bit GhostScript on win64
* :ghissue:`2266`: pyparsing version parsing error
* :ghissue:`2262`: View accepts FirstResponder (for key_press_events)
* :ghissue:`2255`: XKCD-style doesn't work with LineCollection
* :ghissue:`949`: add AOSA chapter link to docs?
* :ghissue:`2147`: Make nonposy='clip' default for log scale y-axes
* :ghissue:`163`: Problem with errorbar in log scale
* :ghissue:`1920`: finance ochl->ohlc
* :ghissue:`2059`: Pep8 on many tests
* :ghissue:`2295`: Vertical text alignment in multi-line legend entries
* :ghissue:`2275`: Fix Qt4 figure editor color setting and getting
* :ghissue:`2274`: Figure editor incorrectly captures color properties
* :ghissue:`2287`: Alpha values smaller than 1/256
* :ghissue:`2279`: Pyparsing
* :ghissue:`2290`: Fix a recursion problem with masked arrays in get_converter
* :ghissue:`2285`: Handle prop=None case in AnchoredText.__init__()
* :ghissue:`2291`: ENH: use an artist's update() method instead of the setp() function
* :ghissue:`2245`: Adding a flush_events method to the MacOSX backend
* :ghissue:`2251`: Remove deprecated code marked for deletion in v1.3
* :ghissue:`2280`: PEP8 on tri module
* :ghissue:`2282`: Extend search path for PyCXX headers
* :ghissue:`2283`: Incorrect overriding of sys.stdout
* :ghissue:`2158`: Changes to anchored_artists.AnchoredSizeBar
* :ghissue:`2284`: plt.hist(...  histtype='step') draws one line too much
* :ghissue:`1939`: GTK error, failed building on command line
* :ghissue:`2272`: zombie webpages
* :ghissue:`2269`: examples/showcase/xkcd.py does not show line randomization on Mac OS X
* :ghissue:`2265`: WebAgg favicon serving error in Python 3
* :ghissue:`2267`: Mention `six` in what's new and install docs
* :ghissue:`2261`: WebAgg performance improvements
* :ghissue:`1547`: qt4_editor/formlayout.py TypeError: float() argument must be a string or a number
* :ghissue:`2206`: 1.3.0rc4: FAIL: No such file or directory: u'.../doc/mpl_toolkits/axes_grid/examples/demo_floating_axis.py'
* :ghissue:`2260`: texmanager font family fix
